@@ -16,14 +16,11 @@
 Pluggable Back-end for Account Server
 """
 
-from uuid import uuid4
 
 import sqlite3
 
-import six
-
-from swift.common.utils import Timestamp
-from swift.common.db import DatabaseBroker, utf8encode, zero_like
+from swift.common.utils import Timestamp, RESERVED_BYTE
+from swift.common.db import DatabaseBroker, zero_like
 
 DATADIR = 'accounts'
 
@@ -154,7 +151,7 @@ class AccountBroker(DatabaseBroker):
         conn.execute('''
             UPDATE account_stat SET account = ?, created_at = ?, id = ?,
                    put_timestamp = ?, status_changed_at = ?
-            ''', (self.account, Timestamp.now().internal, str(uuid4()),
+            ''', (self.account, Timestamp.now().internal, self._new_db_id(),
                   put_timestamp, put_timestamp))
 
     def create_policy_stat_table(self, conn):
@@ -189,20 +186,6 @@ class AccountBroker(DatabaseBroker):
                 self._db_version = 1
         return self._db_version
 
-    def _delete_db(self, conn, timestamp, force=False):
-        """
-        Mark the DB as deleted.
-
-        :param conn: DB connection object
-        :param timestamp: timestamp to mark as deleted
-        """
-        conn.execute("""
-            UPDATE account_stat
-            SET delete_timestamp = ?,
-                status = 'DELETED',
-                status_changed_at = ?
-            WHERE delete_timestamp < ? """, (timestamp, timestamp, timestamp))
-
     def _commit_puts_load(self, item_list, entry):
         """See :func:`swift.common.db.DatabaseBroker._commit_puts_load`"""
         # check to see if the update includes policy_index or not
@@ -369,7 +352,7 @@ class AccountBroker(DatabaseBroker):
             ''').fetchone())
 
     def list_containers_iter(self, limit, marker, end_marker, prefix,
-                             delimiter, reverse=False):
+                             delimiter, reverse=False, allow_reserved=False):
         """
         Get a list of containers sorted by name starting at marker onward, up
         to limit entries. Entries will begin with the prefix and will not have
@@ -381,14 +364,12 @@ class AccountBroker(DatabaseBroker):
         :param prefix: prefix query
         :param delimiter: delimiter for query
         :param reverse: reverse the result order.
+        :param allow_reserved: exclude names with reserved-byte by default
 
         :returns: list of tuples of (name, object_count, bytes_used,
-                  put_timestamp, 0)
+                  put_timestamp, storage_policy_index, is_subdir)
         """
         delim_force_gte = False
-        if six.PY2:
-            (marker, end_marker, prefix, delimiter) = utf8encode(
-                marker, end_marker, prefix, delimiter)
         if reverse:
             # Reverse the markers if we are reversing the listing.
             marker, end_marker = end_marker, marker
@@ -402,7 +383,8 @@ class AccountBroker(DatabaseBroker):
             results = []
             while len(results) < limit:
                 query = """
-                    SELECT name, object_count, bytes_used, put_timestamp, 0
+                    SELECT name, object_count, bytes_used, put_timestamp,
+                    {storage_policy_index}, 0
                     FROM container
                     WHERE """
                 query_args = []
@@ -424,6 +406,9 @@ class AccountBroker(DatabaseBroker):
                 elif prefix:
                     query += ' name >= ? AND'
                     query_args.append(prefix)
+                if not allow_reserved:
+                    query += ' name >= ? AND'
+                    query_args.append(chr(ord(RESERVED_BYTE) + 1))
                 if self.get_db_version(conn) < 1:
                     query += ' +deleted = 0'
                 else:
@@ -431,7 +416,27 @@ class AccountBroker(DatabaseBroker):
                 query += ' ORDER BY name %s LIMIT ?' % \
                          ('DESC' if reverse else '')
                 query_args.append(limit - len(results))
-                curs = conn.execute(query, query_args)
+                try:
+                    # First, try querying with the storage policy index.
+                    curs = conn.execute(
+                        query.format(
+                            storage_policy_index="storage_policy_index"),
+                        query_args)
+                except sqlite3.OperationalError as err:
+                    # If the storage policy column is not available,
+                    # the database has not been migrated to the new schema
+                    # with storage_policy_index. Re-run the query with
+                    # storage_policy_index set to 0, which is what
+                    # would be set once the database is migrated.
+                    # TODO(callumdickinson): If support for migrating
+                    # pre-storage policy versions of Swift is dropped,
+                    # then this special handling can be removed.
+                    if "no such column: storage_policy_index" in str(err):
+                        curs = conn.execute(
+                            query.format(storage_policy_index="0"),
+                            query_args)
+                    else:
+                        raise
                 curs.row_factory = None
 
                 # Delimiters without a prefix is ignored, further if there
@@ -468,7 +473,7 @@ class AccountBroker(DatabaseBroker):
                             delim_force_gte = True
                         dir_name = name[:end + len(delimiter)]
                         if dir_name != orig_marker:
-                            results.append([dir_name, 0, 0, '0', 1])
+                            results.append([dir_name, 0, 0, '0', -1, 1])
                         curs.close()
                         break
                     results.append(row)
