@@ -45,7 +45,6 @@ http://github.com/memcached/memcached/blob/1.4.2/doc/protocol.txt
 """
 
 import os
-import six
 import json
 import logging
 # the name of 'time' module is changed to 'tm', to avoid changing the
@@ -56,9 +55,10 @@ from bisect import bisect
 from eventlet.green import socket, ssl
 from eventlet.pools import Pool
 from eventlet import Timeout
-from six.moves import range
-from six.moves.configparser import ConfigParser, NoSectionError, NoOptionError
+from configparser import ConfigParser, NoSectionError, NoOptionError
 from swift.common import utils
+from swift.common.exceptions import MemcacheConnectionError, \
+    MemcacheIncrNotFoundError, MemcachePoolTimeout
 from swift.common.utils import md5, human_readable, config_true_value, \
     memcached_timing_stats
 
@@ -83,13 +83,13 @@ TIMING_SAMPLE_RATE_HIGH = 0.1
 TIMING_SAMPLE_RATE_MEDIUM = 0.01
 TIMING_SAMPLE_RATE_LOW = 0.001
 
+# The max value of a delta expiration time.
+EXPTIME_MAXDELTA = 30 * 24 * 60 * 60
+
 
 def md5hash(key):
     if not isinstance(key, bytes):
-        if six.PY2:
-            key = key.encode('utf-8')
-        else:
-            key = key.encode('utf-8', errors='surrogateescape')
+        key = key.encode('utf-8', errors='surrogateescape')
     return md5(key, usedforsecurity=False).hexdigest().encode('ascii')
 
 
@@ -100,7 +100,7 @@ def sanitize_timeout(timeout):
     translates negative values to mean a delta of 30 days in seconds (and 1
     additional second), client beware.
     """
-    if timeout > (30 * 24 * 60 * 60):
+    if timeout > EXPTIME_MAXDELTA:
         timeout += tm.time()
     return int(timeout)
 
@@ -119,18 +119,6 @@ def set_msg(key, flags, timeout, value):
     ]) + (b'\r\n' + value + b'\r\n')
 
 
-class MemcacheConnectionError(Exception):
-    pass
-
-
-class MemcacheIncrNotFoundError(MemcacheConnectionError):
-    pass
-
-
-class MemcachePoolTimeout(Timeout):
-    pass
-
-
 class MemcacheConnPool(Pool):
     """
     Connection pool for Memcache Connections
@@ -428,8 +416,7 @@ class MemcacheRing(object):
                     # Wait for the set to complete
                     msg = fp.readline().strip()
                     if msg != b'STORED':
-                        if not six.PY2:
-                            msg = msg.decode('ascii')
+                        msg = msg.decode('ascii')
                         raise MemcacheConnectionError('failed set: %s' % msg)
                     self._return_conn(server, fp, sock)
                     return
