@@ -14,13 +14,12 @@
 # limitations under the License.
 import hashlib
 import hmac
-import six
 
 from swift.common.exceptions import UnknownSecretIdError
 from swift.common.middleware.crypto.crypto_utils import CRYPTO_KEY_CALLBACK
 from swift.common.swob import Request, HTTPException, wsgi_to_str, str_to_wsgi
 from swift.common.utils import readconf, strict_b64decode, get_logger, \
-    split_path
+    split_path, load_multikey_opts
 from swift.common.wsgi import WSGIContext
 
 
@@ -101,14 +100,9 @@ class KeyMasterContext(WSGIContext):
                 # Older py3 proxies may have written down crypto meta as WSGI
                 # strings; we still need to be able to read that
                 try:
-                    if six.PY2:
-                        alt_path = tuple(
-                            part.decode('utf-8').encode('latin1')
-                            for part in (key_acct, key_cont, key_obj))
-                    else:
-                        alt_path = tuple(
-                            part.encode('latin1').decode('utf-8')
-                            for part in (key_acct, key_cont, key_obj))
+                    alt_path = tuple(
+                        part.encode('latin1').decode('utf-8')
+                        for part in (key_acct, key_cont, key_obj))
                 except UnicodeError:
                     # Well, it was worth a shot
                     pass
@@ -208,10 +202,10 @@ class BaseKeyMaster(object):
 
     This provides some basic helpers for:
 
-        - loading from a separate config path,
-        - deriving keys based on path, and
-        - installing a ``swift.callback.fetch_crypto_keys`` hook
-          in the request environment.
+    - loading from a separate config path,
+    - deriving keys based on path, and
+    - installing a ``swift.callback.fetch_crypto_keys`` hook
+      in the request environment.
 
     Subclasses should define ``log_route``, ``keymaster_opts``, and
     ``keymaster_conf_section`` attributes, and implement the
@@ -288,17 +282,6 @@ class BaseKeyMaster(object):
         return readconf(self.keymaster_config_path,
                         self.keymaster_conf_section)
 
-    def _load_multikey_opts(self, conf, prefix):
-        result = []
-        for k, v in conf.items():
-            if not k.startswith(prefix):
-                continue
-            suffix = k[len(prefix):]
-            if suffix and (suffix[0] != '_' or len(suffix) < 2):
-                raise ValueError('Malformed root secret option name %s' % k)
-            result.append((k, suffix[1:] or None, v))
-        return sorted(result)
-
     def __call__(self, env, start_response):
         req = Request(env)
 
@@ -336,8 +319,7 @@ class BaseKeyMaster(object):
             self.logger.warning('Unrecognised secret id: %s' % secret_id)
             raise UnknownSecretIdError(secret_id)
         else:
-            if not six.PY2:
-                path = path.encode('utf-8')
+            path = path.encode('utf-8')
             return hmac.new(key, path, digestmod=hashlib.sha256).digest()
 
 
@@ -373,8 +355,8 @@ class KeyMaster(BaseKeyMaster):
         :rtype: dict
         """
         root_secrets = {}
-        for opt, secret_id, value in self._load_multikey_opts(
-                conf, 'encryption_root_secret'):
+        for opt, secret_id, value in load_multikey_opts(
+                conf, 'encryption_root_secret', allow_none_key=True):
             try:
                 secret = self._decode_root_secret(value)
             except ValueError:
