@@ -43,8 +43,6 @@ http://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html
 """
 from functools import partial
 
-import six
-
 from swift.common.utils import json
 
 from swift.common.middleware.s3api.s3response import InvalidArgument, \
@@ -182,18 +180,19 @@ class Grantee(object):
         """
         Convert a grantee string in the HTTP header to an Grantee instance.
         """
-        type, value = grantee.split('=', 1)
+        grantee_type, value = grantee.split('=', 1)
+        grantee_type = grantee_type.lower()
         value = value.strip('"\'')
-        if type == 'id':
+        if grantee_type == 'id':
             return User(value)
-        elif type == 'emailAddress':
+        elif grantee_type == 'emailaddress':
             raise S3NotImplemented()
-        elif type == 'uri':
+        elif grantee_type == 'uri':
             # return a subclass instance of Group class
             subclass = get_group_subclass_from_uri(value)
             return subclass()
         else:
-            raise InvalidArgument(type, value,
+            raise InvalidArgument(grantee_type, value,
                                   'Argument format not recognized')
 
 
@@ -232,7 +231,7 @@ class Owner(object):
     """
     def __init__(self, id, name):
         self.id = id
-        if not (name is None or isinstance(name, six.string_types)):
+        if not (name is None or isinstance(name, str)):
             raise TypeError('name must be a string or None')
         self.name = name
 
@@ -428,8 +427,6 @@ class ACL(object):
         return tostring(self.elem())
 
     def __repr__(self):
-        if six.PY2:
-            return self.__bytes__()
         return self.__bytes__().decode('utf8')
 
     @classmethod
