@@ -18,7 +18,6 @@ import calendar
 import datetime
 import email.utils
 import re
-import six
 import time
 import uuid
 
@@ -54,8 +53,6 @@ def snake_to_camel(snake):
 
 def unique_id():
     result = base64.urlsafe_b64encode(str(uuid.uuid4()).encode('ascii'))
-    if six.PY2:
-        return result
     return result.decode('ascii')
 
 
@@ -113,13 +110,14 @@ class S3Timestamp(utils.Timestamp):
 
     @property
     def s3xmlformat(self):
-        dt = datetime.datetime.fromtimestamp(self.ceil(), utils.UTC)
+        dt = datetime.datetime.fromtimestamp(
+            self.ceil(), datetime.timezone.utc)
         return dt.strftime(self.S3_XML_FORMAT)
 
     @classmethod
     def from_s3xmlformat(cls, date_string):
         dt = datetime.datetime.strptime(date_string, cls.S3_XML_FORMAT)
-        dt = dt.replace(tzinfo=utils.UTC)
+        dt = dt.replace(tzinfo=datetime.timezone.utc)
         seconds = calendar.timegm(dt.timetuple())
         return cls(seconds)
 
@@ -172,6 +170,7 @@ class Config(dict):
         'allow_no_owner': False,
         'allowable_clock_skew': 900,
         'ratelimit_as_client_error': False,
+        'max_upload_part_num': 1000,
     }
 
     def __init__(self, base=None):
