@@ -15,13 +15,13 @@
 
 import json
 import os
+import sys
 import time
 import traceback
 
 from eventlet import Timeout
 
-import six
-from six.moves.urllib.parse import quote
+from urllib.parse import quote
 
 import swift.common.db
 from swift.container.sync_store import ContainerSyncStore
@@ -35,10 +35,10 @@ from swift.common.request_helpers import split_and_validate_path, \
     validate_container_params
 from swift.common.utils import get_logger, hash_path, public, \
     Timestamp, storage_directory, validate_sync_to, \
-    config_true_value, timing_stats, replication, \
+    config_true_value, replication, \
     override_bytes_from_content_type, get_log_line, \
     config_fallocate_value, fs_has_free_space, list_from_csv, \
-    ShardRange
+    ShardRange, parse_options
 from swift.common.constraints import valid_timestamp, check_utf8, \
     check_drive, AUTO_CREATE_ACCOUNT_PREFIX
 from swift.common.bufferedhttp import http_connect
@@ -46,13 +46,14 @@ from swift.common.exceptions import ConnectionTimeout
 from swift.common.http import HTTP_NO_CONTENT, HTTP_NOT_FOUND, is_success
 from swift.common.middleware import listing_formats
 from swift.common.storage_policy import POLICIES
-from swift.common.base_storage_server import BaseStorageServer
+from swift.common.base_storage_server import BaseStorageServer, timing_stats
 from swift.common.header_key_dict import HeaderKeyDict
 from swift.common.swob import HTTPAccepted, HTTPBadRequest, HTTPConflict, \
     HTTPCreated, HTTPInternalServerError, HTTPNoContent, HTTPNotFound, \
     HTTPPreconditionFailed, HTTPMethodNotAllowed, Request, Response, \
     HTTPInsufficientStorage, HTTPException, HTTPMovedPermanently, \
     wsgi_to_str, str_to_wsgi
+from swift.common.wsgi import run_wsgi
 
 
 def gen_resp_headers(info, is_deleted=False):
@@ -235,10 +236,7 @@ class ContainerController(BaseStorageServer):
             return HTTPBadRequest(req=req)
 
         if account_partition:
-            # zip is lazy on py3, but we need a list, so force evaluation.
-            # On py2 it's an extra list copy, but the list is so small
-            # (one element per replica in account ring, usually 3) that it
-            # doesn't matter.
+            # zip is lazy, but we need a list, so force evaluation.
             updates = list(zip(account_hosts, account_devices))
         else:
             updates = []
@@ -608,6 +606,7 @@ class ContainerController(BaseStorageServer):
             if value != '' and (key.lower() in self.save_headers or
                                 is_sys_or_user_meta('container', key)))
         headers['Content-Type'] = out_content_type
+        headers['Content-Length'] = 0
         resp = HTTPNoContent(request=req, headers=headers, charset='utf-8')
         resp.last_modified = Timestamp(headers['X-PUT-Timestamp']).ceil()
         return resp
@@ -641,11 +640,10 @@ class ContainerController(BaseStorageServer):
         """
         # record is object info
         (name, created, size, content_type, etag) = record[:5]
-        name_ = name.decode('utf8') if six.PY2 else name
         if content_type is None:
-            return {'subdir': name_}
+            return {'subdir': name}
         response = {
-            'bytes': size, 'hash': etag, 'name': name_,
+            'bytes': size, 'hash': etag, 'name': name,
             'content_type': content_type}
         override_bytes_from_content_type(response, logger=self.logger)
         response['last_modified'] = Timestamp(created).isoformat
@@ -1048,3 +1046,12 @@ def app_factory(global_conf, **local_conf):
     conf = global_conf.copy()
     conf.update(local_conf)
     return ContainerController(conf)
+
+
+def main():
+    conf_file, options = parse_options(test_config=True)
+    sys.exit(run_wsgi(conf_file, 'container-server', **options))
+
+
+if __name__ == '__main__':
+    main()
