@@ -426,7 +426,8 @@ class DiskFile(object):
         with self.open(current_time=current_time):
             return self.get_metadata()
 
-    def reader(self, keep_cache=False, cooperative_period=0):
+    def reader(self, keep_cache=False, cooperative_period=0,
+               etag_validate_frac=1):
         """
         Return a swift.common.swob.Response class compatible "app_iter"
         object. The responsibility of closing the open file is passed to the
@@ -434,6 +435,7 @@ class DiskFile(object):
 
         :param keep_cache:
         :param cooperative_period:
+        :param etag_validate_frac:
         """
         dr = DiskFileReader(self._name, self._fp,
                             int(self._metadata['Content-Length']),
