@@ -21,8 +21,7 @@ from os.path import join
 import random
 import time
 from collections import defaultdict
-import six
-import six.moves.cPickle as pickle
+import pickle  # nosec: B403
 import shutil
 
 from eventlet import (GreenPile, GreenPool, Timeout, sleep, tpool, spawn)
@@ -30,11 +29,11 @@ from eventlet.support.greenlets import GreenletExit
 
 from swift.common.utils import (
     whataremyips, unlink_older_than, compute_eta, get_logger,
-    dump_recon_cache, mkdirs, config_true_value,
+    dump_recon_cache, mkdirs, config_true_value, parse_options,
     GreenAsyncPile, Timestamp, remove_file, node_to_string,
     load_recon_cache, parse_override_options, distribute_evenly,
-    PrefixLoggerAdapter, remove_directory, config_request_node_count_value,
-    non_negative_int, parse_options)
+    remove_directory, config_request_node_count_value,
+    non_negative_int, get_prefixed_logger)
 from swift.common.header_key_dict import HeaderKeyDict
 from swift.common.bufferedhttp import http_connect
 from swift.common.daemon import Daemon, run_daemon
@@ -84,7 +83,7 @@ def _full_path(node, part, relative_path, policy):
                    :class:`~swift.common.storage_policy.BaseStoragePolicy`
     :return: string representation of absolute path on node plus policy index
     """
-    if not isinstance(relative_path, six.text_type):
+    if not isinstance(relative_path, str):
         relative_path = relative_path.decode('utf8')
     return '%(node)s/%(part)s%(path)s policy#%(policy)d' % {
         'node': node_to_string(node, replication=True),
@@ -158,11 +157,11 @@ class ObjectReconstructor(Daemon):
     def __init__(self, conf, logger=None):
         """
         :param conf: configuration object obtained from ConfigParser
-        :param logger: logging object
+        :param logger: an instance of ``SwiftLogAdapter``.
         """
         self.conf = conf
-        self.logger = PrefixLoggerAdapter(
-            logger or get_logger(conf, log_route='object-reconstructor'), {})
+        self.logger = \
+            logger or get_logger(conf, log_route='object-reconstructor')
         self.devices_dir = conf.get('devices', '/srv/node')
         self.mount_check = config_true_value(conf.get('mount_check', 'true'))
         self.swift_dir = conf.get('swift_dir', '/etc/swift')
@@ -792,10 +791,12 @@ class ObjectReconstructor(Daemon):
                 (time.time() - self.start))
 
     def _emplace_log_prefix(self, worker_index):
-        self.logger.set_prefix("[worker %d/%d pid=%s] " % (
-            worker_index + 1,  # use 1-based indexing for more readable logs
-            self.reconstructor_workers,
-            os.getpid()))
+        self.logger = get_prefixed_logger(
+            self.logger, "[worker %d/%d pid=%s] " % (
+                worker_index + 1,
+                # use 1-based indexing for more readable logs
+                self.reconstructor_workers,
+                os.getpid()))
 
     def kill_coros(self):
         """Utility function that kills all coroutines currently running."""
@@ -833,6 +834,7 @@ class ObjectReconstructor(Daemon):
         hashed, suffix_hashes = tpool.execute(
             df_mgr._get_hashes, device, partition, policy,
             recalculate=recalculate, do_listdir=do_listdir)
+        # hashed is always an int, we count it in stats but don't return it
         self.logger.update_stats('suffix.hashes', hashed)
         return suffix_hashes
 
@@ -933,7 +935,7 @@ class ObjectReconstructor(Daemon):
                         "Invalid response %(resp)s from %(full_path)s",
                         {'resp': resp.status, 'full_path': full_path})
                 else:
-                    remote_suffixes = pickle.loads(resp.read())
+                    remote_suffixes = pickle.loads(resp.read())  # nosec: B301
             except (Exception, Timeout):
                 # all exceptions are logged here so that our caller can
                 # safely catch our exception and continue to the next node
@@ -1284,11 +1286,11 @@ class ObjectReconstructor(Daemon):
         policy2devices = {}
         for policy in self.policies:
             self.load_object_ring(policy)
-            local_devices = list(six.moves.filter(
-                lambda dev: dev and is_local_device(
+            local_devices = [
+                dev for dev in policy.object_ring.devs
+                if dev and is_local_device(
                     ips, self.port,
-                    dev['replication_ip'], dev['replication_port']),
-                policy.object_ring.devs))
+                    dev['replication_ip'], dev['replication_port'])]
             policy2devices[policy] = local_devices
         return policy2devices
 
