@@ -15,12 +15,12 @@
 
 """ Object Server for Swift """
 
-import six
-import six.moves.cPickle as pickle
-from six.moves.urllib.parse import unquote
+import pickle  # nosec: B403
+from urllib.parse import unquote
 import json
 import os
 import multiprocessing
+import sys
 import time
 import traceback
 import socket
@@ -29,36 +29,45 @@ from eventlet import sleep, wsgi, Timeout, tpool
 from eventlet.greenthread import spawn
 
 from swift.common.utils import public, get_logger, \
-    config_true_value, timing_stats, replication, \
-    normalize_delete_at_timestamp, get_log_line, Timestamp, \
-    get_expirer_container, parse_mime_headers, \
+    config_true_value, config_percent_value, \
+    replication, normalize_delete_at_timestamp, \
+    get_log_line, Timestamp, parse_mime_headers, \
     iter_multipart_mime_documents, extract_swift_bytes, safe_json_loads, \
     config_auto_int_value, split_path, get_redirect_data, \
-    normalize_timestamp, md5
+    normalize_timestamp, md5, parse_options, CooperativeIterator
 from swift.common.bufferedhttp import http_connect
 from swift.common.constraints import check_object_creation, \
     valid_timestamp, check_utf8, AUTO_CREATE_ACCOUNT_PREFIX
 from swift.common.exceptions import ConnectionTimeout, DiskFileQuarantined, \
     DiskFileNotExist, DiskFileCollision, DiskFileNoSpace, DiskFileDeleted, \
     DiskFileDeviceUnavailable, DiskFileExpired, ChunkReadTimeout, \
-    ChunkReadError, DiskFileXattrNotSupported
+    ChunkReadError, DiskFileXattrNotSupported, DiskFileStateChanged
 from swift.common.request_helpers import resolve_ignore_range_header, \
     OBJECT_SYSMETA_CONTAINER_UPDATE_OVERRIDE_PREFIX
-from swift.obj import ssync_receiver
+from swift.obj import ssync_receiver, expirer
 from swift.common.http import is_success, HTTP_MOVED_PERMANENTLY
-from swift.common.base_storage_server import BaseStorageServer
+from swift.common.base_storage_server import BaseStorageServer, \
+    timing_stats, labeled_timing_stats
 from swift.common.header_key_dict import HeaderKeyDict
 from swift.common.request_helpers import get_name_and_placement, \
     is_user_meta, is_sys_or_user_meta, is_object_transient_sysmeta, \
-    resolve_etag_is_at_header, is_sys_meta, validate_internal_obj
+    resolve_etag_is_at_header, is_sys_meta, validate_internal_obj, \
+    is_backend_open_expired
+from swift.common.statsd_client import get_labeled_statsd_client
 from swift.common.swob import HTTPAccepted, HTTPBadRequest, HTTPCreated, \
     HTTPInternalServerError, HTTPNoContent, HTTPNotFound, \
     HTTPPreconditionFailed, HTTPRequestTimeout, HTTPUnprocessableEntity, \
     HTTPClientDisconnect, HTTPMethodNotAllowed, Request, Response, \
     HTTPInsufficientStorage, HTTPForbidden, HTTPException, HTTPConflict, \
-    HTTPServerError, bytes_to_wsgi, wsgi_to_bytes, wsgi_to_str, normalize_etag
+    HTTPServerError, bytes_to_wsgi, wsgi_to_bytes, wsgi_to_str, \
+    normalize_etag, HTTPServiceUnavailable
+from swift.common.wsgi import run_wsgi
 from swift.obj.diskfile import RESERVED_DATAFILE_META, DiskFileRouter
-from swift.obj.expirer import build_task_obj
+from swift.obj.expirer import build_task_obj, embed_expirer_bytes_in_ctype, \
+    X_DELETE_TYPE
+
+
+LABELED_METRIC_NAME = 'swift_object_server_request_timing'
 
 
 def iter_mime_headers_and_bodies(wsgi_input, mime_boundary, read_chunk_size):
@@ -138,6 +147,7 @@ class ObjectController(BaseStorageServer):
         """
         super(ObjectController, self).__init__(conf)
         self.logger = logger or get_logger(conf, log_route='object-server')
+        self.statsd = get_labeled_statsd_client(conf, self.logger.logger)
         self.node_timeout = float(conf.get('node_timeout', 3))
         self.container_update_timeout = float(
             conf.get('container_update_timeout', 1))
@@ -153,6 +163,8 @@ class ObjectController(BaseStorageServer):
         self.keep_cache_slo_manifest = \
             config_true_value(conf.get('keep_cache_slo_manifest', 'false'))
         self.cooperative_period = int(conf.get("cooperative_period", 0))
+        self.etag_validate_frac = config_percent_value(
+            conf.get("etag_validate_pct", 100))
 
         default_allowed_headers = '''
             content-disposition,
@@ -176,10 +188,7 @@ class ObjectController(BaseStorageServer):
                 self.allowed_headers.add(header)
 
         self.auto_create_account_prefix = AUTO_CREATE_ACCOUNT_PREFIX
-        self.expiring_objects_account = self.auto_create_account_prefix + \
-            (conf.get('expiring_objects_account_name') or 'expiring_objects')
-        self.expiring_objects_container_divisor = \
-            int(conf.get('expiring_objects_container_divisor') or 86400)
+        self.expirer_config = expirer.ExpirerConfig(conf, logger=self.logger)
         # Initialization was successful, so now apply the network chunk size
         # parameter as the default read / write buffer size for the network
         # sockets.
@@ -194,8 +203,8 @@ class ObjectController(BaseStorageServer):
         # disk_chunk_size parameter. However, it affects all created sockets
         # using this class so we have chosen to tie it to the
         # network_chunk_size parameter value instead.
-        if six.PY2:
-            socket._fileobject.default_bufsize = self.network_chunk_size
+        # if six.PY2:
+        #    socket._fileobject.default_bufsize = self.network_chunk_size
         # TODO: find a way to enable similar functionality in py3
 
         # Provide further setup specific to an object server implementation.
@@ -268,7 +277,8 @@ class ObjectController(BaseStorageServer):
 
     def async_update(self, op, account, container, obj, host, partition,
                      contdevice, headers_out, objdevice, policy,
-                     logger_thread_locals=None, container_path=None):
+                     logger_thread_locals=None, container_path=None,
+                     db_state=None):
         """
         Sends or saves an async update.
 
@@ -290,6 +300,8 @@ class ObjectController(BaseStorageServer):
             to which the update should be sent. If given this path will be used
             instead of constructing a path from the ``account`` and
             ``container`` params.
+        :param db_state: The current database state of the container as
+            supplied to us by the proxy.
         """
         if logger_thread_locals:
             self.logger.thread_locals = logger_thread_locals
@@ -333,7 +345,7 @@ class ObjectController(BaseStorageServer):
                     '%(ip)s:%(port)s/%(dev)s (saving for async update later)',
                     {'ip': ip, 'port': port, 'dev': contdevice})
         data = {'op': op, 'account': account, 'container': container,
-                'obj': obj, 'headers': headers_out}
+                'obj': obj, 'headers': headers_out, 'db_state': db_state}
         if redirect_data:
             self.logger.debug(
                 'Update to %(path)s redirected to %(redirect)s',
@@ -367,6 +379,7 @@ class ObjectController(BaseStorageServer):
         contdevices = [d.strip() for d in
                        headers_in.get('X-Container-Device', '').split(',')]
         contpartition = headers_in.get('X-Container-Partition', '')
+        contdbstate = headers_in.get('X-Container-Root-Db-State')
 
         if len(conthosts) != len(contdevices):
             # This shouldn't happen unless there's a bug in the proxy,
@@ -417,7 +430,7 @@ class ObjectController(BaseStorageServer):
                        conthost, contpartition, contdevice, headers_out,
                        objdevice, policy,
                        logger_thread_locals=self.logger.thread_locals,
-                       container_path=contpath)
+                       container_path=contpath, db_state=contdbstate)
             update_greenthreads.append(gt)
         # Wait a little bit to see if the container updates are successful.
         # If we immediately return after firing off the greenthread above, then
@@ -436,7 +449,7 @@ class ObjectController(BaseStorageServer):
                 self.container_update_timeout, updates)
 
     def delete_at_update(self, op, delete_at, account, container, obj,
-                         request, objdevice, policy):
+                         request, objdevice, policy, extra_headers=None):
         """
         Update the expiring objects container when objects are updated.
 
@@ -448,15 +461,14 @@ class ObjectController(BaseStorageServer):
         :param request: the original request driving the update
         :param objdevice: device name that the object is in
         :param policy: the BaseStoragePolicy instance (used for tmp dir)
+        :param extra_headers: dict of additional headers for the update
         """
         if config_true_value(
                 request.headers.get('x-backend-replication', 'f')):
             return
-        delete_at = normalize_delete_at_timestamp(delete_at)
-        updates = [(None, None)]
 
-        partition = None
-        hosts = contdevices = [None]
+        delete_at = normalize_delete_at_timestamp(delete_at)
+
         headers_in = request.headers
         headers_out = HeaderKeyDict({
             # system accounts are always Policy-0
@@ -464,26 +476,42 @@ class ObjectController(BaseStorageServer):
             'x-timestamp': request.timestamp.internal,
             'x-trans-id': headers_in.get('x-trans-id', '-'),
             'referer': request.as_referer()})
+
+        expiring_objects_account_name, delete_at_container = \
+            self.expirer_config.get_expirer_account_and_container(
+                delete_at, account, container, obj)
         if op != 'DELETE':
             hosts = headers_in.get('X-Delete-At-Host', None)
             if hosts is None:
                 # If header is missing, no update needed as sufficient other
                 # object servers should perform the required update.
                 return
-            delete_at_container = headers_in.get('X-Delete-At-Container', None)
-            if not delete_at_container:
-                # older proxy servers did not send X-Delete-At-Container so for
-                # backwards compatibility calculate the value here, but also
-                # log a warning because this is prone to inconsistent
-                # expiring_objects_container_divisor configurations.
-                # See https://bugs.launchpad.net/swift/+bug/1187200
-                self.logger.warning(
-                    'X-Delete-At-Container header must be specified for '
-                    'expiring objects background %s to work properly. Making '
-                    'best guess as to the container name for now.' % op)
-                delete_at_container = get_expirer_container(
-                    delete_at, self.expiring_objects_container_divisor,
-                    account, container, obj)
+
+            proxy_delete_at_container = headers_in.get(
+                'X-Delete-At-Container', None)
+            if delete_at_container != proxy_delete_at_container:
+                if not proxy_delete_at_container:
+                    # We carry this warning around for pre-2013 proxies
+                    self.logger.warning(
+                        'X-Delete-At-Container header must be specified for '
+                        'expiring objects background %s to work properly. '
+                        'Making best guess as to the container name '
+                        'for now.', op)
+                    proxy_delete_at_container = delete_at_container
+                else:
+                    # Inconsistent configuration may lead to orphaned expirer
+                    # task queue objects when X-Delete-At is updated, which can
+                    # stick around for a whole reclaim age.
+                    self.logger.debug(
+                        'Proxy X-Delete-At-Container %r does not match '
+                        'expected %r for current expirer_config.',
+                        proxy_delete_at_container, delete_at_container)
+                # it's not possible to say which is "more correct", this will
+                # at least match the host/part/device
+                delete_at_container = normalize_delete_at_timestamp(
+                    proxy_delete_at_container)
+
+            # new updates need to enqueue new x-delete-at
             partition = headers_in.get('X-Delete-At-Partition', None)
             contdevices = headers_in.get('X-Delete-At-Device', '')
             updates = [upd for upd in
@@ -493,30 +521,22 @@ class ObjectController(BaseStorageServer):
             if not updates:
                 updates = [(None, None)]
             headers_out['x-size'] = '0'
-            headers_out['x-content-type'] = 'text/plain'
+            headers_out['x-content-type'] = X_DELETE_TYPE
             headers_out['x-etag'] = 'd41d8cd98f00b204e9800998ecf8427e'
+            if extra_headers:
+                headers_out.update(extra_headers)
         else:
             if not config_true_value(
                 request.headers.get(
                     'X-Backend-Clean-Expiring-Object-Queue', 't')):
                 return
-
-            # DELETEs of old expiration data have no way of knowing what the
-            # old X-Delete-At-Container was at the time of the initial setting
-            # of the data, so a best guess is made here.
-            # Worst case is a DELETE is issued now for something that doesn't
-            # exist there and the original data is left where it is, where
-            # it will be ignored when the expirer eventually tries to issue the
-            # object DELETE later since the X-Delete-At value won't match up.
-            delete_at_container = get_expirer_container(
-                delete_at, self.expiring_objects_container_divisor,
-                account, container, obj)
-        delete_at_container = normalize_delete_at_timestamp(
-            delete_at_container)
+            # DELETE op always go directly to async_pending
+            partition = None
+            updates = [(None, None)]
 
         for host, contdevice in updates:
             self.async_update(
-                op, self.expiring_objects_account, delete_at_container,
+                op, expiring_objects_account_name, delete_at_container,
                 build_task_obj(delete_at, account, container, obj),
                 host, partition, contdevice, headers_out, objdevice,
                 policy)
@@ -619,12 +639,34 @@ class ObjectController(BaseStorageServer):
                     override = key.lower().replace(override_prefix, 'x-')
                     update_headers[override] = val
 
+    def _conditional_delete_at_update(self, request, device, account,
+                                      container, obj, policy, metadata,
+                                      orig_delete_at, new_delete_at):
+        if new_delete_at:
+            extra_headers = {
+                'x-content-type': embed_expirer_bytes_in_ctype(
+                    X_DELETE_TYPE, metadata),
+                'x-content-type-timestamp':
+                metadata.get('X-Timestamp'),
+            }
+            self.delete_at_update(
+                'PUT', new_delete_at, account, container, obj, request,
+                device, policy, extra_headers)
+        if orig_delete_at and orig_delete_at != new_delete_at:
+            self.delete_at_update(
+                'DELETE', orig_delete_at, account, container, obj,
+                request, device, policy)
+
     @public
     @timing_stats()
-    def POST(self, request):
+    @labeled_timing_stats(metric=LABELED_METRIC_NAME)
+    def POST(self, request, timing_stats_labels):
         """Handle HTTP POST requests for the Swift Object Server."""
         device, partition, account, container, obj, policy = \
             get_obj_name_and_placement(request)
+        timing_stats_labels['account'] = account
+        timing_stats_labels['container'] = container
+        timing_stats_labels['policy'] = int(policy)
 
         req_timestamp = valid_timestamp(request)
         new_delete_at = int(request.headers.get('X-Delete-At') or 0)
@@ -635,8 +677,7 @@ class ObjectController(BaseStorageServer):
         try:
             disk_file = self.get_diskfile(
                 device, partition, account, container, obj,
-                policy=policy, open_expired=config_true_value(
-                    request.headers.get('x-backend-replication', 'false')),
+                policy=policy, open_expired=is_backend_open_expired(request),
                 next_part_power=next_part_power)
         except DiskFileDeviceUnavailable:
             return HTTPInsufficientStorage(drive=device, request=request)
@@ -646,6 +687,8 @@ class ObjectController(BaseStorageServer):
             return HTTPInsufficientStorage(drive=device, request=request)
         except (DiskFileNotExist, DiskFileQuarantined):
             return HTTPNotFound(request=request)
+        except DiskFileStateChanged:
+            return HTTPServiceUnavailable(request=request)
         orig_timestamp = Timestamp(orig_metadata.get('X-Timestamp', 0))
         orig_ctype_timestamp = disk_file.content_type_timestamp
         req_ctype_time = '0'
@@ -675,15 +718,11 @@ class ObjectController(BaseStorageServer):
                         wsgi_to_bytes(header_key).title())
                     metadata[header_caps] = request.headers[header_key]
             orig_delete_at = int(orig_metadata.get('X-Delete-At') or 0)
-            if orig_delete_at != new_delete_at:
-                if new_delete_at:
-                    self.delete_at_update(
-                        'PUT', new_delete_at, account, container, obj, request,
-                        device, policy)
-                if orig_delete_at:
-                    self.delete_at_update('DELETE', orig_delete_at, account,
-                                          container, obj, request, device,
-                                          policy)
+            disk_file_metadata = disk_file.get_datafile_metadata()
+            self._conditional_delete_at_update(
+                request, device, account, container, obj, policy,
+                disk_file_metadata, orig_delete_at, new_delete_at
+            )
         else:
             # preserve existing metadata, only content-type may be updated
             metadata = dict(disk_file.get_metafile_metadata())
@@ -805,7 +844,8 @@ class ObjectController(BaseStorageServer):
         except DiskFileDeleted as e:
             orig_metadata = {}
             orig_timestamp = e.timestamp
-        except (DiskFileNotExist, DiskFileQuarantined):
+        except (DiskFileNotExist, DiskFileQuarantined,
+                DiskFileStateChanged):
             orig_metadata = {}
             orig_timestamp = Timestamp(0)
         # Checks for If-None-Match
@@ -884,13 +924,20 @@ class ObjectController(BaseStorageServer):
         elapsed_time = 0
         upload_expiration = time.time() + self.max_upload_time
         timeout_reader = self._make_timeout_reader(obj_input)
-        for chunk in iter(timeout_reader, b''):
+
+        # Wrap the chunks in CooperativeIterator with specified period
+        cooperative_reader = CooperativeIterator(
+            iter(timeout_reader, b''), period=self.cooperative_period
+        )
+
+        for chunk in cooperative_reader:
             start_time = time.time()
             if start_time > upload_expiration:
                 self.logger.increment('PUT.timeouts')
                 raise HTTPRequestTimeout(request=request)
             writer.write(chunk)
             elapsed_time += time.time() - start_time
+
         upload_size, etag = writer.chunks_finished()
         if fsize is not None and fsize != upload_size:
             raise HTTPClientDisconnect(request=request)
@@ -993,15 +1040,10 @@ class ObjectController(BaseStorageServer):
                              orig_metadata, footers_metadata, metadata):
         orig_delete_at = int(orig_metadata.get('X-Delete-At') or 0)
         new_delete_at = int(request.headers.get('X-Delete-At') or 0)
-        if orig_delete_at != new_delete_at:
-            if new_delete_at:
-                self.delete_at_update(
-                    'PUT', new_delete_at, account, container, obj, request,
-                    device, policy)
-            if orig_delete_at:
-                self.delete_at_update(
-                    'DELETE', orig_delete_at, account, container, obj,
-                    request, device, policy)
+
+        self._conditional_delete_at_update(request, device, account, container,
+                                           obj, policy, metadata,
+                                           orig_delete_at, new_delete_at)
 
         update_headers = HeaderKeyDict({
             'x-size': metadata['Content-Length'],
@@ -1017,10 +1059,15 @@ class ObjectController(BaseStorageServer):
 
     @public
     @timing_stats()
-    def PUT(self, request):
+    @labeled_timing_stats(metric=LABELED_METRIC_NAME)
+    def PUT(self, request, timing_stats_labels):
         """Handle HTTP PUT requests for the Swift Object Server."""
         device, partition, account, container, obj, policy = \
             get_obj_name_and_placement(request)
+        timing_stats_labels['account'] = account
+        timing_stats_labels['container'] = container
+        timing_stats_labels['policy'] = int(policy)
+
         disk_file, fsize, orig_metadata = self._pre_create_checks(
             request, device, partition, account, container, obj, policy)
         writer = disk_file.writer(size=fsize)
@@ -1061,10 +1108,15 @@ class ObjectController(BaseStorageServer):
 
     @public
     @timing_stats()
-    def GET(self, request):
+    @labeled_timing_stats(metric=LABELED_METRIC_NAME)
+    def GET(self, request, timing_stats_labels):
         """Handle HTTP GET requests for the Swift Object Server."""
         device, partition, account, container, obj, policy = \
             get_obj_name_and_placement(request)
+        timing_stats_labels['account'] = account
+        timing_stats_labels['container'] = container
+        timing_stats_labels['policy'] = int(policy)
+
         request.headers.setdefault('X-Timestamp',
                                    normalize_timestamp(time.time()))
         req_timestamp = valid_timestamp(request)
@@ -1074,8 +1126,7 @@ class ObjectController(BaseStorageServer):
             disk_file = self.get_diskfile(
                 device, partition, account, container, obj,
                 policy=policy, frag_prefs=frag_prefs,
-                open_expired=config_true_value(
-                    request.headers.get('x-backend-replication', 'false')))
+                open_expired=is_backend_open_expired(request))
         except DiskFileDeviceUnavailable:
             return HTTPInsufficientStorage(drive=device, request=request)
         try:
@@ -1101,6 +1152,7 @@ class ObjectController(BaseStorageServer):
                 app_iter = disk_file.reader(
                     keep_cache=keep_cache,
                     cooperative_period=self.cooperative_period,
+                    etag_validate_frac=self.etag_validate_frac,
                 )
                 response = Response(
                     app_iter=app_iter, request=request,
@@ -1140,14 +1192,21 @@ class ObjectController(BaseStorageServer):
                 headers['X-Backend-Timestamp'] = e.timestamp.internal
             resp = HTTPNotFound(request=request, headers=headers,
                                 conditional_response=True)
+        except DiskFileStateChanged:
+            resp = HTTPServiceUnavailable(request=request)
         return resp
 
     @public
     @timing_stats(sample_rate=0.8)
-    def HEAD(self, request):
+    @labeled_timing_stats(metric=LABELED_METRIC_NAME)
+    def HEAD(self, request, timing_stats_labels):
         """Handle HTTP HEAD requests for the Swift Object Server."""
         device, partition, account, container, obj, policy = \
             get_obj_name_and_placement(request)
+        timing_stats_labels['account'] = account
+        timing_stats_labels['container'] = container
+        timing_stats_labels['policy'] = int(policy)
+
         request.headers.setdefault('X-Timestamp',
                                    normalize_timestamp(time.time()))
         req_timestamp = valid_timestamp(request)
@@ -1157,8 +1216,7 @@ class ObjectController(BaseStorageServer):
             disk_file = self.get_diskfile(
                 device, partition, account, container, obj,
                 policy=policy, frag_prefs=frag_prefs,
-                open_expired=config_true_value(
-                    request.headers.get('x-backend-replication', 'false')))
+                open_expired=is_backend_open_expired(request))
         except DiskFileDeviceUnavailable:
             return HTTPInsufficientStorage(drive=device, request=request)
         try:
@@ -1171,6 +1229,8 @@ class ObjectController(BaseStorageServer):
                 headers['X-Backend-Timestamp'] = e.timestamp.internal
             return HTTPNotFound(request=request, headers=headers,
                                 conditional_response=True)
+        except DiskFileStateChanged:
+            return HTTPServiceUnavailable(request=request)
         conditional_etag = resolve_etag_is_at_header(request, metadata)
         response = Response(request=request, conditional_response=True,
                             conditional_etag=conditional_etag)
@@ -1203,10 +1263,15 @@ class ObjectController(BaseStorageServer):
 
     @public
     @timing_stats()
-    def DELETE(self, request):
+    @labeled_timing_stats(metric=LABELED_METRIC_NAME)
+    def DELETE(self, request, timing_stats_labels):
         """Handle HTTP DELETE requests for the Swift Object Server."""
         device, partition, account, container, obj, policy = \
             get_obj_name_and_placement(request)
+        timing_stats_labels['account'] = account
+        timing_stats_labels['container'] = container
+        timing_stats_labels['policy'] = int(policy)
+
         req_timestamp = valid_timestamp(request)
         next_part_power = request.headers.get('X-Backend-Next-Part-Power')
         try:
@@ -1231,6 +1296,12 @@ class ObjectController(BaseStorageServer):
             orig_timestamp = 0
             orig_metadata = {}
             response_class = HTTPNotFound
+        except DiskFileStateChanged:
+            # Bail out early because unread metadata may have an X-Delete-At.
+            # This condition can occur when a concurrent request has replaced
+            # the data or meta file that this thread was trying to open. Force
+            # client to retry, hoping the on-disk files have settled.
+            return HTTPServiceUnavailable(request=request)
         else:
             orig_timestamp = disk_file.data_timestamp
             if orig_timestamp < req_timestamp:
@@ -1264,10 +1335,10 @@ class ObjectController(BaseStorageServer):
             else:
                 # differentiate success from no object at all
                 response_class = HTTPNoContent
-        if orig_delete_at:
-            self.delete_at_update('DELETE', orig_delete_at, account,
-                                  container, obj, request, device,
-                                  policy)
+        self._conditional_delete_at_update(
+            request, device, account, container, obj, policy, {},
+            orig_delete_at, 0
+        )
         if orig_timestamp < req_timestamp:
             try:
                 disk_file.delete(req_timestamp)
@@ -1286,7 +1357,8 @@ class ObjectController(BaseStorageServer):
     @public
     @replication
     @timing_stats(sample_rate=0.1)
-    def REPLICATE(self, request):
+    @labeled_timing_stats(metric=LABELED_METRIC_NAME)
+    def REPLICATE(self, request, timing_stats_labels):
         """
         Handle REPLICATE requests for the Swift Object Server.  This is used
         by the object replicator to get hashes for directories.
@@ -1298,10 +1370,14 @@ class ObjectController(BaseStorageServer):
         device, partition, suffix_parts, policy = \
             get_name_and_placement(request, 2, 3, True)
         suffixes = suffix_parts.split('-') if suffix_parts else []
+        skip_rehash = bool(suffixes)
+        timing_stats_labels['policy'] = int(policy)
+        timing_stats_labels['skip_rehash'] = skip_rehash
+
         try:
             hashes = self._diskfile_router[policy].get_hashes(
                 device, partition, suffixes, policy,
-                skip_rehash=bool(suffixes))
+                skip_rehash=skip_rehash)
         except DiskFileDeviceUnavailable:
             resp = HTTPInsufficientStorage(drive=device, request=request)
         else:
@@ -1312,15 +1388,17 @@ class ObjectController(BaseStorageServer):
     @public
     @replication
     @timing_stats(sample_rate=0.1)
-    def SSYNC(self, request):
+    @labeled_timing_stats(metric=LABELED_METRIC_NAME)
+    def SSYNC(self, request, timing_stats_labels):
         # the ssync sender may want to send PUT subrequests for non-durable
         # data that should not be committed; legacy behaviour has been to
         # commit all PUTs (subject to EC footer metadata), so we need to
         # indicate to the sender that this object server has been upgraded to
         # understand the X-Backend-No-Commit header.
         headers = {'X-Backend-Accept-No-Commit': True}
-        return Response(app_iter=ssync_receiver.Receiver(self, request)(),
-                        headers=headers)
+        receiver = ssync_receiver.Receiver(self, request)
+        timing_stats_labels['policy'] = int(receiver.policy)
+        return Response(app_iter=receiver(), headers=headers)
 
     def __call__(self, env, start_response):
         """WSGI Application entry point for the Swift Object Server."""
@@ -1443,3 +1521,14 @@ def app_factory(global_conf, **local_conf):
     conf = global_conf.copy()
     conf.update(local_conf)
     return ObjectController(conf)
+
+
+def main():
+    conf_file, options = parse_options(test_config=True)
+    sys.exit(run_wsgi(conf_file, 'object-server',
+                      global_conf_callback=global_conf_callback,
+                      **options))
+
+
+if __name__ == '__main__':
+    main()
