@@ -13,7 +13,7 @@
 
 from swift.proxy.controllers.base import Controller
 from swift.proxy.controllers.info import InfoController
-from swift.proxy.controllers.obj import ObjectController
+from swift.proxy.controllers.obj import ObjectControllerRouter
 from swift.proxy.controllers.account import AccountController
 from swift.proxy.controllers.container import ContainerController
 
@@ -22,5 +22,5 @@ __all__ = [
     'ContainerController',
     'Controller',
     'InfoController',
-    'ObjectController',
+    'ObjectControllerRouter',
 ]
