@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from six.moves.urllib.parse import unquote
+from urllib.parse import unquote
 
 from swift.account.utils import account_listing_response
 from swift.common.middleware.acl import parse_acl, format_acl
