@@ -56,11 +56,17 @@ class TestS3ApiXxeInjection(S3ApiBaseBoto3):
             # https://github.com/boto/boto3/issues/2192
             self.conn.meta.events.register(
                 'before-sign.s3.*', self._clear_data)
-            return self.conn.generate_presigned_url(
+            url = self.conn.generate_presigned_url(
                 method, Params=params, ExpiresIn=60)
         finally:
             self.conn.meta.events.unregister(
                 'before-sign.s3.*', self._clear_data)
+        if not params.get('Key') and '/?' not in url:
+            # Some combination of dependencies seems to cause bucket requests
+            # to not get the trailing slash despite signing with it? But only
+            # new-enough versions sign with the trailing slash
+            url = url.replace('?', '/?')
+        return url
 
     def test_put_bucket_acl(self):
         if not tf.cluster_info['s3api'].get('s3_acl'):
