@@ -13,12 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import print_function
 
 import errno
 import gc
 import json
-import mock
+from unittest import mock
 import os
 from subprocess import Popen, PIPE
 import sys
@@ -29,9 +28,8 @@ from collections import defaultdict
 import unittest
 from uuid import uuid4
 import shutil
-import six
-from six.moves.http_client import HTTPConnection
-from six.moves.urllib.parse import urlparse
+from http.client import HTTPConnection
+from urllib.parse import urlparse
 
 from swiftclient import get_auth, head_account, client
 from swift.common import internal_client, direct_client, utils
@@ -342,9 +340,6 @@ class Body(object):
         self.hasher.update(rv)
         return rv
 
-    # for py2 compat:
-    next = __next__
-
 
 def exclude_nodes(nodes, *excludes):
     """
@@ -555,16 +550,18 @@ class ProbeTest(unittest.TestCase):
         for policy in ENABLED_POLICIES:
             for dev in policy.object_ring.devs:
                 all_obj_nodes[dev['device']] = dev
-        return all_obj_nodes.values()
+        return list(all_obj_nodes.values())
 
-    def gather_async_pendings(self, onodes):
+    def gather_async_pendings(self, onodes=None):
         """
         Returns a list of paths to async pending files found on given nodes.
 
-        :param onodes: a list of nodes.
+        :param onodes: a list of nodes. If None, check all object nodes.
         :return: a list of file paths.
         """
         async_pendings = []
+        if onodes is None:
+            onodes = self.get_all_object_nodes()
         for onode in onodes:
             device_dir = self.device_dir(onode)
             for ap_pol_dir in os.listdir(device_dir):
@@ -721,16 +718,9 @@ class ECProbeTest(ProbeTest):
         if not require_durable:
             req_headers.update(
                 {'X-Backend-Fragment-Preferences': json.dumps([])})
-        # node dict has unicode values so utf8 decode our path parts too in
-        # case they have non-ascii characters
-        if six.PY2:
-            acc, con, obj = (s.decode('utf8') for s in (
-                self.account, self.container_name, self.object_name))
-        else:
-            acc, con, obj = self.account, self.container_name, self.object_name
         headers, data = direct_client.direct_get_object(
-            node, part, acc, con, obj, headers=req_headers,
-            resp_chunk_size=64 * 2 ** 20)
+            node, part, self.account, self.container_name, self.object_name,
+            headers=req_headers, resp_chunk_size=64 * 2 ** 20)
         hasher = md5(usedforsecurity=False)
         for chunk in data:
             hasher.update(chunk)
