@@ -13,16 +13,19 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
-from contextlib import contextmanager
+import itertools
 import unittest
 import uuid
 import random
 import time
-import six
 
 from swift.common.direct_client import DirectClientException
+from swift.common.header_key_dict import HeaderKeyDict
+from swift.common.internal_client import UnexpectedResponse
+from swift.common.manager import Manager
+from swift.common.swob import wsgi_to_str, str_to_wsgi
 from swift.common.utils import md5
+from swift.obj.reconstructor import ObjectReconstructor
 from test.probe.common import ECProbeTest
 
 from swift.common import direct_client
@@ -52,14 +55,12 @@ class Body(object):
         self.hasher.update(self.chunk)
         return self.chunk
 
-    # for py2 compat
-    next = __next__
-
 
 class TestReconstructorRebuild(ECProbeTest):
 
     def setUp(self):
         super(TestReconstructorRebuild, self).setUp()
+        self.int_client = self.make_internal_client()
         # create EC container
         headers = {'X-Storage-Policy': self.policy.name}
         client.put_container(self.url, self.token, self.container_name,
@@ -84,6 +85,19 @@ class TestReconstructorRebuild(ECProbeTest):
                 'X-Backend-Durable-Timestamp', hdrs,
                 'Missing durable timestamp in %r' % self.frag_headers)
 
+    def proxy_get(self):
+        # Use internal-client instead of python-swiftclient, since we can't
+        # handle UTF-8 headers properly w/ swiftclient.
+        # Still a proxy-server tho!
+        status, headers, body = self.int_client.get_object(
+            self.account,
+            self.container_name.decode('utf-8'),
+            self.object_name.decode('utf-8'))
+        resp_checksum = md5(usedforsecurity=False)
+        for chunk in body:
+            resp_checksum.update(chunk)
+        return HeaderKeyDict(headers), resp_checksum.hexdigest()
+
     def _format_node(self, node):
         return '%s#%s' % (node['device'], node['index'])
 
@@ -107,47 +121,53 @@ class TestReconstructorRebuild(ECProbeTest):
                                  for (node, exc) in failures]))
         return frag_headers, frag_etags
 
-    @contextmanager
-    def _annotate_failure_with_scenario(self, failed, non_durable):
-        try:
-            yield
-        except (AssertionError, ClientException) as err:
-            self.fail(
-                'Scenario with failed nodes: %r, non-durable nodes: %r\n'
-                ' failed with:\n%s' %
-                ([self._format_node(self.onodes[n]) for n in failed],
-                 [self._format_node(self.onodes[n]) for n in non_durable], err)
-            )
-
     def _test_rebuild_scenario(self, failed, non_durable,
                                reconstructor_cycles):
         # helper method to test a scenario with some nodes missing their
         # fragment and some nodes having non-durable fragments
-        with self._annotate_failure_with_scenario(failed, non_durable):
+        with self.subTest(
+                failed=[self._format_node(self.onodes[n]) for n in failed],
+                non_durable=[self._format_node(self.onodes[n])
+                             for n in non_durable]):
             self.break_nodes(self.onodes, self.opart, failed, non_durable)
 
         # make sure we can still GET the object and it is correct; the
         # proxy is doing decode on remaining fragments to get the obj
-        with self._annotate_failure_with_scenario(failed, non_durable):
+        with self.subTest(
+                failed=[self._format_node(self.onodes[n]) for n in failed],
+                non_durable=[self._format_node(self.onodes[n])
+                             for n in non_durable]):
             headers, etag = self.proxy_get()
             self.assertEqual(self.etag, etag)
             for key in self.headers_post:
-                self.assertIn(key, headers)
-                self.assertEqual(self.headers_post[key], headers[key])
+                # Since we use internal_client for the GET, headers come back
+                # as WSGI strings
+                wsgi_key = str_to_wsgi(key)
+                self.assertIn(wsgi_key, headers)
+                self.assertEqual(self.headers_post[key],
+                                 wsgi_to_str(headers[wsgi_key]))
 
         # fire up reconstructor
         for i in range(reconstructor_cycles):
             self.reconstructor.once()
 
         # check GET via proxy returns expected data and metadata
-        with self._annotate_failure_with_scenario(failed, non_durable):
+        with self.subTest(
+                failed=[self._format_node(self.onodes[n]) for n in failed],
+                non_durable=[self._format_node(self.onodes[n])
+                             for n in non_durable]):
             headers, etag = self.proxy_get()
             self.assertEqual(self.etag, etag)
             for key in self.headers_post:
-                self.assertIn(key, headers)
-                self.assertEqual(self.headers_post[key], headers[key])
+                wsgi_key = str_to_wsgi(key)
+                self.assertIn(wsgi_key, headers)
+                self.assertEqual(self.headers_post[key],
+                                 wsgi_to_str(headers[wsgi_key]))
         # check all frags are intact, durable and have expected metadata
-        with self._annotate_failure_with_scenario(failed, non_durable):
+        with self.subTest(
+                failed=[self._format_node(self.onodes[n]) for n in failed],
+                non_durable=[self._format_node(self.onodes[n])
+                             for n in non_durable]):
             frag_headers, frag_etags = self._assert_all_nodes_have_frag()
             self.assertEqual(self.frag_etags, frag_etags)
             # self._frag_headers include X-Backend-Durable-Timestamp so this
@@ -270,8 +290,8 @@ class TestReconstructorRebuild(ECProbeTest):
         while time.time() < timeout:
             try:
                 self.proxy_get()
-            except ClientException as e:
-                if e.http_status == 404:
+            except UnexpectedResponse as e:
+                if e.resp.status_int == 404:
                     break
                 else:
                     raise
@@ -369,13 +389,173 @@ class TestReconstructorRebuild(ECProbeTest):
                     'X-Backend-Storage-Policy-Index': int(self.policy)})
             self.assertNotIn('X-Delete-At', headers)
 
+    def test_rebuild_quarantines_lonely_frag(self):
+        # fail one device while the object is deleted so we are left with one
+        # fragment and some tombstones
+        failed_node = self.onodes[0]
+        device_path = self.device_dir(failed_node)
+        self.kill_drive(device_path)
+        self.assert_direct_get_fails(failed_node, self.opart, 507)  # sanity
 
-if six.PY2:
-    class TestReconstructorRebuildUTF8(TestReconstructorRebuild):
+        # delete object
+        client.delete_object(self.url, self.token, self.container_name,
+                             self.object_name)
 
-        def _make_name(self, prefix):
-            return b'%s\xc3\xa8-%s' % (
-                prefix.encode(), str(uuid.uuid4()).encode())
+        # check we have tombstones
+        for node in self.onodes[1:]:
+            err = self.assert_direct_get_fails(node, self.opart, 404)
+            self.assertIn('X-Backend-Timestamp', err.http_headers)
+
+        # run the reconstructor with zero reclaim age to clean up tombstones
+        for conf_index in self.configs['object-reconstructor'].keys():
+            self.run_custom_daemon(
+                ObjectReconstructor, 'object-reconstructor', conf_index,
+                {'reclaim_age': '0'})
+
+        # check we no longer have tombstones
+        for node in self.onodes[1:]:
+            err = self.assert_direct_get_fails(node, self.opart, 404)
+            self.assertNotIn('X-Timestamp', err.http_headers)
+
+        # revive the failed device and check it has a fragment
+        self.revive_drive(device_path)
+        self.assert_direct_get_succeeds(failed_node, self.opart)
+
+        # restart proxy to clear error-limiting so that the revived drive
+        # participates again
+        Manager(['proxy-server']).restart()
+
+        # client GET will fail with 503 ...
+        with self.assertRaises(ClientException) as cm:
+            client.get_object(self.url, self.token, self.container_name,
+                              self.object_name)
+        self.assertEqual(503, cm.exception.http_status)
+        # ... but client HEAD succeeds
+
+        path = self.int_client.make_path(
+            self.account,
+            self.container_name.decode('utf-8'),
+            self.object_name.decode('utf-8'))
+        resp = self.int_client.make_request(
+            'HEAD', path, {}, acceptable_statuses=(2,))
+        for key in self.headers_post:
+            wsgi_key = str_to_wsgi(key)
+            self.assertIn(wsgi_key, resp.headers)
+            self.assertEqual(self.headers_post[key],
+                             wsgi_to_str(resp.headers[wsgi_key]))
+
+        # run the reconstructor without quarantine_threshold set
+        error_lines = []
+        warning_lines = []
+        for conf_index in self.configs['object-reconstructor'].keys():
+            reconstructor = self.run_custom_daemon(
+                ObjectReconstructor, 'object-reconstructor', conf_index,
+                {'quarantine_age': '0'})
+            logger = reconstructor.logger
+            error_lines.append(logger.get_lines_for_level('error'))
+            warning_lines.append(logger.get_lines_for_level('warning'))
+
+        # check logs for errors
+        found_lines = False
+        for lines in error_lines:
+            if not lines:
+                continue
+            self.assertFalse(found_lines, error_lines)
+            found_lines = True
+            for line in itertools.islice(lines, 0, 6, 2):
+                self.assertIn(
+                    'Unable to get enough responses (1/4 from 1 ok '
+                    'responses)', line, lines)
+            for line in itertools.islice(lines, 1, 7, 2):
+                self.assertIn(
+                    'Unable to get enough responses (4 x 404 error '
+                    'responses)', line, lines)
+        self.assertTrue(found_lines, 'error lines not found')
+
+        for lines in warning_lines:
+            self.assertEqual([], lines)
+
+        # check we have still have a single fragment and no tombstones
+        self.assert_direct_get_succeeds(failed_node, self.opart)
+        for node in self.onodes[1:]:
+            err = self.assert_direct_get_fails(node, self.opart, 404)
+            self.assertNotIn('X-Timestamp', err.http_headers)
+
+        # run the reconstructor to quarantine the lonely frag
+        error_lines = []
+        warning_lines = []
+        for conf_index in self.configs['object-reconstructor'].keys():
+            reconstructor = self.run_custom_daemon(
+                ObjectReconstructor, 'object-reconstructor', conf_index,
+                {'quarantine_age': '0', 'quarantine_threshold': '1'})
+            logger = reconstructor.logger
+            error_lines.append(logger.get_lines_for_level('error'))
+            warning_lines.append(logger.get_lines_for_level('warning'))
+
+        # check logs for errors
+        found_lines = False
+        for index, lines in enumerate(error_lines):
+            if not lines:
+                continue
+            self.assertFalse(found_lines, error_lines)
+            found_lines = True
+            for line in itertools.islice(lines, 0, 6, 2):
+                self.assertIn(
+                    'Unable to get enough responses (1/4 from 1 ok '
+                    'responses)', line, lines)
+            for line in itertools.islice(lines, 1, 7, 2):
+                self.assertIn(
+                    'Unable to get enough responses (6 x 404 error '
+                    'responses)', line, lines)
+        self.assertTrue(found_lines, 'error lines not found')
+
+        # check logs for quarantine warning
+        found_lines = False
+        for lines in warning_lines:
+            if not lines:
+                continue
+            self.assertFalse(found_lines, warning_lines)
+            found_lines = True
+            self.assertEqual(1, len(lines), lines)
+            self.assertIn('Quarantined object', lines[0])
+        self.assertTrue(found_lines, 'warning lines not found')
+
+        # check we have nothing
+        for node in self.onodes:
+            err = self.assert_direct_get_fails(node, self.opart, 404)
+            self.assertNotIn('X-Backend-Timestamp', err.http_headers)
+        # client HEAD and GET now both 404
+        with self.assertRaises(ClientException) as cm:
+            client.get_object(self.url, self.token, self.container_name,
+                              self.object_name)
+        self.assertEqual(404, cm.exception.http_status)
+        with self.assertRaises(ClientException) as cm:
+            client.head_object(self.url, self.token, self.container_name,
+                               self.object_name)
+        self.assertEqual(404, cm.exception.http_status)
+
+        # run the reconstructor once more - should see no errors in logs!
+        error_lines = []
+        warning_lines = []
+        for conf_index in self.configs['object-reconstructor'].keys():
+            reconstructor = self.run_custom_daemon(
+                ObjectReconstructor, 'object-reconstructor', conf_index,
+                {'quarantine_age': '0', 'quarantine_threshold': '1'})
+            logger = reconstructor.logger
+            error_lines.append(logger.get_lines_for_level('error'))
+            warning_lines.append(logger.get_lines_for_level('warning'))
+
+        for lines in error_lines:
+            self.assertEqual([], lines)
+        for lines in warning_lines:
+            self.assertEqual([], lines)
+
+
+class TestReconstructorRebuildUTF8(TestReconstructorRebuild):
+
+    def _make_name(self, prefix):
+        return b'%s\xc3\xa8-%s' % (
+            prefix.encode(), str(uuid.uuid4()).encode())
 
 
 if __name__ == "__main__":
