@@ -20,7 +20,7 @@ import copy
 import logging
 import logging.handlers
 import sys
-from contextlib import contextmanager, closing
+from contextlib import contextmanager
 from collections import defaultdict
 from collections.abc import Iterable
 import itertools
@@ -39,14 +39,13 @@ import errno
 import xattr
 from io import BytesIO
 from uuid import uuid4
-import pickle
 from http.client import HTTPException
 
 from swift.common import storage_policy, swob, utils, exceptions
 from swift.common.memcached import MemcacheConnectionError
 from swift.common.storage_policy import (StoragePolicy, ECStoragePolicy,
                                          VALID_EC_TYPES)
-from swift.common.utils import Timestamp, md5, close_if_possible
+from swift.common.utils import Timestamp, md5, close_if_possible, checksum
 from test import get_config
 from test.debug_logger import FakeLogger
 from swift.common.header_key_dict import HeaderKeyDict
@@ -54,7 +53,6 @@ from swift.common.ring import Ring, RingData, RingBuilder
 from swift.obj import server
 
 import functools
-from gzip import GzipFile
 from unittest import mock as mocklib
 import inspect
 from unittest import SkipTest
@@ -303,10 +301,10 @@ def write_fake_ring(path, *devs):
     """
     Pretty much just a two node, two replica, 2 part power ring...
     """
-    dev1 = {'id': 0, 'zone': 0, 'device': 'sda1', 'ip': '127.0.0.1',
-            'port': 6200}
-    dev2 = {'id': 1, 'zone': 0, 'device': 'sdb1', 'ip': '127.0.0.1',
-            'port': 6200}
+    dev1 = {'id': 0, 'region': 1, 'zone': 0, 'device': 'sda1',
+            'ip': '127.0.0.1', 'port': 6200}
+    dev2 = {'id': 1, 'region': 1, 'zone': 0, 'device': 'sdb1',
+            'ip': '127.0.0.1', 'port': 6200}
 
     dev1_updates, dev2_updates = devs or ({}, {})
 
@@ -316,8 +314,7 @@ def write_fake_ring(path, *devs):
     replica2part2dev_id = [[0, 1, 0, 1], [1, 0, 1, 0]]
     devs = [dev1, dev2]
     part_shift = 30
-    with closing(GzipFile(path, 'wb')) as f:
-        pickle.dump(RingData(replica2part2dev_id, devs, part_shift), f)
+    RingData(replica2part2dev_id, devs, part_shift).save(path)
 
 
 def write_stub_builder(tmpdir, region=1, name=''):
@@ -1085,6 +1082,28 @@ def requires_o_tmpfile_support_in_tmp(func):
     return wrapper
 
 
+def requires_crc32c(func):
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        try:
+            checksum.crc32c()
+        except NotImplementedError as e:
+            raise SkipTest(str(e))
+        return func(*args, **kwargs)
+    return wrapper
+
+
+def requires_crc64nvme(func):
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        try:
+            checksum.crc64nvme()
+        except NotImplementedError as e:
+            raise SkipTest(str(e))
+        return func(*args, **kwargs)
+    return wrapper
+
+
 class StubResponse(object):
 
     def __init__(self, status, body=b'', headers=None, frag_index=None,
