@@ -15,12 +15,11 @@
 from argparse import Namespace
 import os
 import unittest
-import mock
+from unittest import mock
 from shutil import rmtree
 from tempfile import mkdtemp
 
-import six
-from six.moves import cStringIO as StringIO
+from io import StringIO
 from test.unit import patch_policies, write_fake_ring, skip_if_no_xattrs
 
 from swift.common import ring, utils
@@ -29,7 +28,7 @@ from swift.common.storage_policy import StoragePolicy, POLICIES
 from swift.cli.info import (print_db_info_metadata, print_ring_locations,
                             print_info, print_obj_metadata, print_obj,
                             InfoSystemExit, print_item_locations,
-                            parse_get_node_args)
+                            parse_get_node_args, print_db_syncs)
 from swift.account.server import AccountController
 from swift.container.server import ContainerController
 from swift.container.backend import UNSHARDED, SHARDED
@@ -139,7 +138,8 @@ Metadata:
   UUID: abadf100d0ddba11
   X-Other-Something: boo
 No system metadata found in db file
-  User Metadata: {'x-account-meta-mydata': 'swift'}'''
+  User Metadata:
+    x-account-meta-mydata: swift'''
 
         self.assertEqual(out.getvalue().strip().split('\n'),
                          exp_out.split('\n'))
@@ -190,7 +190,8 @@ Metadata:
   UUID: abadf100d0ddba11
   X-Container-Bar: goo
   X-Container-Foo: bar
-  System Metadata: {'mydata': 'swift'}
+  System Metadata:
+    mydata: swift
 No user metadata found in db file
 Sharding Metadata:
   Type: root
@@ -232,7 +233,8 @@ Metadata:
   UUID: abadf100d0ddba11
   X-Other-Something: boo
 No system metadata found in db file
-  User Metadata: {'x-account-meta-mydata': 'swift'}'''
+  User Metadata:
+    x-account-meta-mydata: swift'''
 
         self.assertEqual(sorted(out.getvalue().strip().split('\n')),
                          sorted(exp_out.split('\n')))
@@ -420,12 +422,8 @@ Shard Ranges (19):
         out = StringIO()
         with mock.patch('sys.stdout', out):
             print_db_info_metadata('container', info, {}, verbose=True)
-        if six.PY2:
-            s_a = '\\xe3\\x82\\xa2'
-            s_ya = '\\xe3\\x83\\xa4'
-        else:
-            s_a = '\u30a2'
-            s_ya = '\u30e4'
+        s_a = '\u30a2'
+        s_ya = '\u30e4'
         exp_out = '''Path: /acct/cont
   Account: acct
   Container: cont
@@ -552,7 +550,7 @@ Shard Ranges (3):
             # Test mismatch of ring and policy name (valid policy)
             self.assertRaises(InfoSystemExit, print_item_locations,
                               objring, policy_name='zero')
-        self.assertIn('Warning: mismatch between ring and policy name!',
+        self.assertIn('WARNING: mismatch between ring and policy name!',
                       out.getvalue())
         self.assertIn('No target specified', out.getvalue())
 
@@ -563,7 +561,7 @@ Shard Ranges (3):
             objring = ring.Ring(self.testdir, ring_name='object')
             self.assertRaises(InfoSystemExit, print_item_locations,
                               objring, policy_name=policy_name)
-        exp_msg = 'Warning: Policy %s is not valid' % policy_name
+        exp_msg = 'WARNING: Policy %s is not valid' % policy_name
         self.assertIn(exp_msg, out.getvalue())
         self.assertIn('No target specified', out.getvalue())
 
@@ -600,7 +598,7 @@ Shard Ranges (3):
             print_item_locations(account_ring, account=account)
         exp_msg = 'Account  \t%s' % account
         self.assertIn(exp_msg, out.getvalue())
-        exp_warning = 'Warning: account specified ' + \
+        exp_warning = 'WARNING: account specified ' + \
                       'but ring not named "account"'
         self.assertIn(exp_warning, out.getvalue())
         exp_acct_msg = 'Account  \t%s' % account
@@ -663,6 +661,40 @@ Shard Ranges (3):
         self.assertIn(exp_cont_msg, out.getvalue())
         self.assertIn(exp_obj_msg, out.getvalue())
 
+    def test_print_db_syncs(self):
+        # first the empty case
+        for incoming in (True, False):
+            out = StringIO()
+            with mock.patch('sys.stdout', out):
+                print_db_syncs(incoming, [])
+            if incoming:
+                exp_heading = 'Incoming Syncs:'
+            else:
+                exp_heading = 'Outgoing Syncs:'
+            exp_heading += '\n  Sync Point\tRemote ID\tUpdated At'
+            self.assertIn(exp_heading, out.getvalue())
+
+        # now add some syncs
+        ts0 = utils.Timestamp(1)
+        ts1 = utils.Timestamp(2)
+        syncs = [{'sync_point': 0, 'remote_id': 'remote_0',
+                  'updated_at': str(int(ts0))},
+                 {'sync_point': 1, 'remote_id': 'remote_1',
+                  'updated_at': str(int(ts1))}]
+
+        template_output = """%s:\n  Sync Point\tRemote ID\tUpdated At
+  0         \tremote_0 \t%s (%s)
+  1         \tremote_1 \t%s (%s)
+"""
+        for incoming in (True, False):
+            out = StringIO()
+            with mock.patch('sys.stdout', out):
+                print_db_syncs(incoming, syncs)
+            output = template_output % (
+                'Incoming Syncs' if incoming else 'Outgoing Syncs',
+                ts0.isoformat, str(int(ts0)), ts1.isoformat, str(int(ts1)))
+            self.assertEqual(output, out.getvalue())
+
     def test_print_item_locations_account_container_object_dashed_ring(self):
         out = StringIO()
         account = 'account'
@@ -1219,7 +1251,7 @@ class TestPrintObjFullMeta(TestCliInfoBase):
             md = {'name': '/AUTH_admin/c/obj',
                   'Content-Type': 'application/octet-stream',
                   'ETag': 'd41d8cd98f00b204e9800998ecf8427e',
-                  'Content-Length': 0}
+                  'Content-Length': '0'}
             write_metadata(fp, md)
 
     def test_print_obj(self):
@@ -1256,7 +1288,7 @@ class TestPrintObjFullMeta(TestCliInfoBase):
             md = {'name': '/AUTH_admin/c/obj',
                   'Content-Type': 'application/octet-stream',
                   'ETag': 'd41d8cd98f00b204e9800998ecf8427e',
-                  'Content-Length': 0}
+                  'Content-Length': '0'}
             write_metadata(fp, md)
 
         object_ring = ring.Ring(self.testdir, ring_name='object-2')
@@ -1297,7 +1329,7 @@ class TestPrintObjFullMeta(TestCliInfoBase):
             md = {'name': '/AUTH_admin/c/obj',
                   'Content-Type': 'application/octet-stream',
                   'ETag': 'd41d8cd98f00b204e9800998ecf8427e',
-                  'Content-Length': 0}
+                  'Content-Length': '0'}
             write_metadata(fp, md)
 
         object_ring = ring.Ring(self.testdir, ring_name='object-3')
@@ -1353,7 +1385,7 @@ class TestPrintObjFullMeta(TestCliInfoBase):
         out = StringIO()
         with mock.patch('sys.stdout', out):
             print_obj(self.datafile, policy_name='two', swift_dir=self.testdir)
-        ring_alert_msg = 'Warning: Ring does not match policy!'
+        ring_alert_msg = 'WARNING: Ring does not match policy!'
         self.assertIn(ring_alert_msg, out.getvalue())
 
     def test_valid_etag(self):
@@ -1368,7 +1400,7 @@ class TestPrintObjFullMeta(TestCliInfoBase):
             md = {'name': '/AUTH_admin/c/obj',
                   'Content-Type': 'application/octet-stream',
                   'ETag': 'badetag',
-                  'Content-Length': 0}
+                  'Content-Length': '0'}
             write_metadata(fp, md)
 
         out = StringIO()
@@ -1703,5 +1735,5 @@ class TestPrintObjWeirdPath(TestPrintObjFullMeta):
             md = {'name': '/AUTH_admin/c/obj',
                   'Content-Type': 'application/octet-stream',
                   'ETag': 'd41d8cd98f00b204e9800998ecf8427e',
-                  'Content-Length': 0}
+                  'Content-Length': '0'}
             write_metadata(fp, md)
