@@ -17,18 +17,18 @@ import json
 import os
 import unittest
 
-import mock
+from unittest import mock
 
 from swift.common.request_helpers import is_object_transient_sysmeta
 from swift.common.utils import MD5_OF_EMPTY_STRING
 from swift.common.header_key_dict import HeaderKeyDict
-from swift.common.middleware.crypto import decrypter
+from swift.common.middleware.crypto import decrypter, keymaster
 from swift.common.middleware.crypto.crypto_utils import CRYPTO_KEY_CALLBACK, \
     dump_crypto_meta, Crypto, load_crypto_meta
 from swift.common.swob import Request, HTTPException, HTTPOk, \
     HTTPPreconditionFailed, HTTPNotFound, HTTPPartialContent, bytes_to_wsgi
 
-from test.unit import FakeLogger
+from test.debug_logger import debug_logger
 from test.unit.common.middleware.crypto.crypto_helpers import md5hex, \
     fetch_crypto_keys, FAKE_IV, encrypt, fake_get_crypto_meta
 from test.unit.common.middleware.helpers import FakeSwift, FakeAppThatExcepts
@@ -52,7 +52,7 @@ class TestDecrypterObjectRequests(unittest.TestCase):
     def setUp(self):
         self.app = FakeSwift()
         self.decrypter = decrypter.Decrypter(self.app, {})
-        self.decrypter.logger = FakeLogger()
+        self.decrypter.logger = debug_logger()
 
     def _make_response_headers(self, content_length, plaintext_etag, keys,
                                body_key, key_id=None):
@@ -125,6 +125,7 @@ class TestDecrypterObjectRequests(unittest.TestCase):
             resp.headers['X-Object-Sysmeta-Container-Update-Override-Etag'])
         self.assertNotIn('X-Object-Sysmeta-Crypto-Body-Meta', resp.headers)
         self.assertNotIn('X-Object-Sysmeta-Crypto-Etag', resp.headers)
+        self.assertNotIn('Access-Control-Expose-Headers', resp.headers)
         return resp
 
     def test_GET_success(self):
@@ -226,6 +227,7 @@ class TestDecrypterObjectRequests(unittest.TestCase):
         self.assertEqual(plaintext_etag, resp.headers['Etag'])
         self.assertEqual('text/plain', resp.headers['Content-Type'])
         self.assertEqual('encrypt me', resp.headers['x-object-meta-test'])
+        self.assertNotIn('Access-Control-Expose-Headers', resp.headers)
         return resp
 
     def test_GET_unencrypted_data_and_encrypted_metadata(self):
@@ -259,6 +261,7 @@ class TestDecrypterObjectRequests(unittest.TestCase):
         self.assertEqual(plaintext_etag, resp.headers['Etag'])
         self.assertEqual('text/plain', resp.headers['Content-Type'])
         self.assertEqual('unencrypted', resp.headers['x-object-meta-test'])
+        self.assertNotIn('Access-Control-Expose-Headers', resp.headers)
         return resp
 
     def test_GET_encrypted_data_and_unencrypted_metadata(self):
@@ -271,7 +274,8 @@ class TestDecrypterObjectRequests(unittest.TestCase):
 
     def test_headers_case(self):
         body = b'fAkE ApP'
-        req = Request.blank('/v1/a/c/o', body='FaKe')
+        req = Request.blank('/v1/a/c/o', body='FaKe', headers={
+            'Origin': 'http://example.com'})
         req.environ[CRYPTO_KEY_CALLBACK] = fetch_crypto_keys
         plaintext_etag = md5hex(body)
         body_key = os.urandom(32)
@@ -281,7 +285,10 @@ class TestDecrypterObjectRequests(unittest.TestCase):
 
         hdrs.update({
             'x-Object-mEta-ignoRes-caSe': 'thIs pArt WilL bE cOol',
+            'access-control-Expose-Headers': 'x-object-meta-ignores-case',
+            'access-control-allow-origin': '*',
         })
+        self.assertNotIn('x-object-meta-test', [k.lower() for k in hdrs])
         self.app.register(
             'GET', '/v1/a/c/o', HTTPOk, body=enc_body, headers=hdrs)
 
@@ -296,6 +303,11 @@ class TestDecrypterObjectRequests(unittest.TestCase):
             'X-Object-Meta-Ignores-Case': 'thIs pArt WilL bE cOol',
             'X-Object-Sysmeta-Test': 'do not encrypt me',
             'Content-Type': 'text/plain',
+            'Access-Control-Expose-Headers': ', '.join([
+                'x-object-meta-ignores-case',
+                'x-object-meta-test',
+            ]),
+            'Access-Control-Allow-Origin': '*',
         }
         self.assertEqual(dict(headers), expected)
         self.assertEqual(b'fAkE ApP', b''.join(app_iter))
@@ -983,7 +995,7 @@ class TestDecrypterContainerRequests(unittest.TestCase):
     def setUp(self):
         self.app = FakeSwift()
         self.decrypter = decrypter.Decrypter(self.app, {})
-        self.decrypter.logger = FakeLogger()
+        self.decrypter.logger = debug_logger()
 
     def _make_cont_get_req(self, resp_body, format, override=False,
                            callback=fetch_crypto_keys):
@@ -1199,6 +1211,30 @@ class TestDecrypter(unittest.TestCase):
             req.get_response(app)
         self.assertEqual(FakeAppThatExcepts.MESSAGE, catcher.exception.body)
 
+    def test_non_swift_path(self):
+        path = '/\xC0.\xC0./\xC0.\xC0./\xC0.\xC0./\xC0.\xC0./winnt/win.ini'
+        fake_swift = FakeSwift()
+        fake_swift.register('GET', path, HTTPNotFound, {})
+        app = keymaster.KeyMaster(decrypter.Decrypter(fake_swift, {}), {
+            'encryption_root_secret': 'A' * 80,
+        })
+        app.app.logger = debug_logger()
+        req = Request.blank(path)
+        resp = req.get_response(app)
+        self.assertEqual(resp.status_int, 404)
+
+    def test_invalid_swift_path(self):
+        path = '/v1/\xC0.\xC0./\xC0.\xC0./\xC0.\xC0./\xC0.\xC0./winnt/win.ini'
+        fake_swift = FakeSwift()
+        fake_swift.register('GET', path, HTTPNotFound, {})
+        app = keymaster.KeyMaster(decrypter.Decrypter(fake_swift, {}), {
+            'encryption_root_secret': 'A' * 80,
+        })
+        app.app.logger = debug_logger()
+        req = Request.blank(path)
+        resp = req.get_response(app)
+        self.assertEqual(resp.status_int, 404)
+
 
 if __name__ == '__main__':
     unittest.main()
