@@ -15,10 +15,12 @@
 # limitations under the License.
 
 import base64
+import io
 import unittest
 from unittest.mock import patch, MagicMock
 import calendar
 from datetime import datetime
+from datetime import timezone
 from unittest import mock
 import requests
 import json
@@ -34,7 +36,7 @@ from swift.common.middleware.keystoneauth import KeystoneAuth
 from swift.common import swob, registry
 from swift.common.request_helpers import get_log_info
 from swift.common.swob import Request
-from swift.common.utils import md5, get_logger, UTC
+from swift.common.utils import md5, get_logger
 
 from keystonemiddleware.auth_token import AuthProtocol
 from keystoneauth1.access import AccessInfoV2
@@ -238,10 +240,25 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual('proxy-server', s3api.logger.server)
         self.assertEqual('s3api.', s3api.logger.logger.statsd_client._prefix)
         client = s3api.logger.logger.statsd_client
-        self.assertEqual({'test-metric': 1}, client.get_increment_counts())
+        self.assertEqual({'test-metric': 1}, client.get_stats_counts())
         self.assertEqual([(b's3api.test-metric:1|c', ('1.2.3.4', 8125))],
                          client.sendto_calls)
 
+    def test_init_logs_checksum_implementation(self):
+        with mock.patch('swift.common.middleware.s3api.s3api.get_logger',
+                        return_value=self.logger), \
+                mock.patch('swift.common.utils.checksum.crc32c_isal') \
+                as mock_crc32c, \
+                mock.patch('swift.common.utils.checksum.crc64nvme_isal') \
+                as mock_crc64nvme:
+            mock_crc32c.__name__ = 'crc32c_isal'
+            mock_crc64nvme.__name__ = 'crc64nvme_isal'
+            S3ApiMiddleware(None, {})
+        self.assertEqual(
+            {'info': ['Using crc32c_isal implementation for CRC32C.',
+                      'Using crc64nvme_isal implementation for CRC64NVME.']},
+            self.logger.all_log_lines())
+
     def test_non_s3_request_passthrough(self):
         req = Request.blank('/something')
         status, headers, body = self.call_s3api(req)
@@ -255,7 +272,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'AccessDenied')
         self.assertEqual(
             {'403.AccessDenied.invalid_header_auth': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.invalid_header_auth',
                          get_log_info(req.environ))
 
@@ -268,7 +285,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'MethodNotAllowed')
         self.assertEqual(
             {'405.MethodNotAllowed': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:MethodNotAllowed',
                          get_log_info(req.environ))
 
@@ -282,7 +299,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'MethodNotAllowed')
         self.assertEqual(
             {'405.MethodNotAllowed': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:MethodNotAllowed',
                          get_log_info(req.environ))
 
@@ -319,6 +336,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
                 'PATH_INFO': path,
                 'QUERY_STRING': query_string,
                 'HTTP_AUTHORIZATION': 'AWS X:Y:Z',
+                'wsgi.input': io.BytesIO(),
             }
             for header, value in headers.items():
                 header = 'HTTP_' + header.replace('-', '_').upper()
@@ -412,13 +430,13 @@ class TestS3ApiMiddleware(S3ApiTestCase):
                             'AWSAccessKeyId=test:tester' % expire,
                             environ={'REQUEST_METHOD': 'GET'},
                             headers={'Date': self.get_date_header()})
-        req.headers['Date'] = datetime.now(UTC)
+        req.headers['Date'] = datetime.now(timezone.utc)
         req.content_type = 'text/plain'
         status, headers, body = self.call_s3api(req)
         self.assertEqual(self._get_error_code(body), 'AccessDenied')
         self.assertEqual(
             {'403.AccessDenied.expired': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.expired',
                          get_log_info(req.environ))
 
@@ -426,7 +444,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         # Set expire to last 32b timestamp value
         # This number can't be higher, because it breaks tests on 32b systems
         expire = '2147483647'  # 19 Jan 2038 03:14:07
-        utc_date = datetime.now(UTC)
+        utc_date = datetime.now(timezone.utc)
         req = Request.blank('/bucket/object?Signature=X&Expires=%s&'
                             'AWSAccessKeyId=test:tester&Timestamp=%s' %
                             (expire, utc_date.isoformat().rsplit('.')[0]),
@@ -463,13 +481,13 @@ class TestS3ApiMiddleware(S3ApiTestCase):
                             'AWSAccessKeyId=test:tester' % expire,
                             environ={'REQUEST_METHOD': 'GET'},
                             headers={'Date': self.get_date_header()})
-        req.headers['Date'] = datetime.now(UTC)
+        req.headers['Date'] = datetime.now(timezone.utc)
         req.content_type = 'text/plain'
         status, headers, body = self.call_s3api(req)
         self.assertEqual(self._get_error_code(body), 'AccessDenied')
         self.assertEqual(
             {'403.AccessDenied.invalid_expires': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.invalid_expires',
                          get_log_info(req.environ))
 
@@ -479,13 +497,13 @@ class TestS3ApiMiddleware(S3ApiTestCase):
                             'AWSAccessKeyId=test:tester' % expire,
                             environ={'REQUEST_METHOD': 'GET'},
                             headers={'Date': self.get_date_header()})
-        req.headers['Date'] = datetime.now(UTC)
+        req.headers['Date'] = datetime.now(timezone.utc)
         req.content_type = 'text/plain'
         status, headers, body = self.call_s3api(req)
         self.assertEqual(self._get_error_code(body), 'AccessDenied')
         self.assertEqual(
             {'403.AccessDenied.invalid_query_auth': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.invalid_query_auth',
                          get_log_info(req.environ))
 
@@ -494,13 +512,13 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         req = Request.blank('/bucket/object?Expires=%s&'
                             'AWSAccessKeyId=' % expire,
                             environ={'REQUEST_METHOD': 'GET'})
-        req.headers['Date'] = datetime.now(UTC)
+        req.headers['Date'] = datetime.now(timezone.utc)
         req.content_type = 'text/plain'
         status, headers, body = self.call_s3api(req)
         self.assertEqual(self._get_error_code(body), 'AccessDenied')
         self.assertEqual(
             {'403.AccessDenied.invalid_query_auth': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.invalid_query_auth',
                          get_log_info(req.environ))
 
@@ -518,7 +536,11 @@ class TestS3ApiMiddleware(S3ApiTestCase):
             headers={'Date': self.get_date_header()},
             environ={'REQUEST_METHOD': 'GET'})
         req.content_type = 'text/plain'
-        status, headers, body = self.call_s3api(req)
+
+        # Test with ProxyLoggingMiddleware for access_user_id logging for
+        # presigned URLs
+        app = ProxyLoggingMiddleware(self.s3api, {}, logger=self.logger)
+        status, headers, body = self.call_app(req, app=app)
         self.assertIn('swift.backend_path', req.environ)
         self.assertEqual('/v1/AUTH_test/bucket/object',
                          req.environ['swift.backend_path'])
@@ -527,6 +549,16 @@ class TestS3ApiMiddleware(S3ApiTestCase):
             self.assertNotIn('Authorization', headers)
             self.assertNotIn('X-Auth-Token', headers)
 
+        # Verify access_user_id is logged correctly for V4 presigned URLs
+        access_lines = self.logger.get_lines_for_level('info')
+        self.assertEqual(1, len(access_lines))
+        parts = access_lines[0].split()
+        # For presigned URLs, the logged path includes query parameters
+        self.assertTrue(' '.join(parts[3:6]).startswith('GET /bucket/object'))
+        self.assertEqual(parts[5], 'HTTP/1.0')
+        self.assertEqual(parts[6], '200')
+        self.assertEqual(parts[-1], 'test:tester')  # access_user_id
+
     def test_signed_urls_v4_bad_credential(self):
         def test(credential, message, extra=b''):
             req = Request.blank(
@@ -551,7 +583,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
             self.assertIn(extra, body)
             self.assertEqual(
                 {'400.AuthorizationQueryParametersError': 1},
-                self.s3api.logger.logger.statsd_client.get_increment_counts())
+                self.s3api.logger.logger.statsd_client.get_stats_counts())
             self.assertEqual('s3:err:AuthorizationQueryParametersError',
                              get_log_info(req.environ))
 
@@ -584,7 +616,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'AccessDenied')
         self.assertEqual(
             {'403.AccessDenied.invalid_date': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.invalid_date',
                          get_log_info(req.environ))
 
@@ -604,7 +636,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'InvalidArgument')
         self.assertEqual(
             {'400.InvalidArgument': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:InvalidArgument',
                          get_log_info(req.environ))
 
@@ -624,7 +656,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
                          'AuthorizationHeaderMalformed')
         self.assertEqual(
             {'400.AuthorizationHeaderMalformed': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AuthorizationHeaderMalformed',
                          get_log_info(req.environ))
 
@@ -643,7 +675,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'AccessDenied')
         self.assertEqual(
             {'403.AccessDenied.invalid_credential': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.invalid_credential',
                          get_log_info(req.environ))
 
@@ -662,7 +694,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'AccessDenied')
         self.assertEqual(
             {'403.AccessDenied.invalid_query_auth': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.invalid_query_auth',
                          get_log_info(req.environ))
 
@@ -706,7 +738,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         date_header = self.get_date_header()
         req.headers['Date'] = date_header
         with mock.patch('swift.common.middleware.s3api.s3request.'
-                        'S3Request.check_signature') as mock_cs:
+                        'SigCheckerV2.check_signature') as mock_cs:
             status, headers, body = self.call_s3api(req)
             self.assertIn('swift.backend_path', req.environ)
             self.assertEqual(
@@ -737,7 +769,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         date_header = self.get_date_header()
         req.headers['Date'] = date_header
         with mock.patch('swift.common.middleware.s3api.s3request.'
-                        'S3Request.check_signature') as mock_cs:
+                        'SigCheckerV2.check_signature') as mock_cs:
             status, headers, body = self.call_s3api(req)
             self.assertIn('swift.backend_path', req.environ)
             self.assertEqual(
@@ -762,7 +794,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'InvalidURI')
         self.assertEqual(
             {'400.InvalidURI': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:InvalidURI', get_log_info(req.environ))
 
     def test_object_create_bad_md5_unreadable(self):
@@ -775,7 +807,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'InvalidDigest')
         self.assertEqual(
             {'400.InvalidDigest': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:InvalidDigest', get_log_info(req.environ))
 
     def test_object_create_bad_md5_too_short(self):
@@ -791,7 +823,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'InvalidDigest')
         self.assertEqual(
             {'400.InvalidDigest': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:InvalidDigest', get_log_info(req.environ))
 
     def test_object_create_bad_md5_bad_padding(self):
@@ -808,7 +840,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'InvalidDigest')
         self.assertEqual(
             {'400.InvalidDigest': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:InvalidDigest', get_log_info(req.environ))
 
     def test_object_create_bad_md5_too_long(self):
@@ -825,7 +857,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'InvalidDigest')
         self.assertEqual(
             {'400.InvalidDigest': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:InvalidDigest', get_log_info(req.environ))
 
     def test_invalid_metadata_directive(self):
@@ -839,7 +871,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'InvalidArgument')
         self.assertEqual(
             {'400.InvalidArgument': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:InvalidArgument',
                          get_log_info(req.environ))
 
@@ -853,7 +885,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'InvalidStorageClass')
         self.assertEqual(
             {'400.InvalidStorageClass': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:InvalidStorageClass',
                          get_log_info(req.environ))
 
@@ -867,7 +899,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'InvalidArgument')
         self.assertEqual(
             {'400.InvalidArgument': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:InvalidArgument',
                          get_log_info(req.environ))
 
@@ -884,7 +916,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'NotImplemented')
         self.assertEqual(
             {'501.NotImplemented': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:NotImplemented',
                          get_log_info(req.environ))
 
@@ -919,23 +951,6 @@ class TestS3ApiMiddleware(S3ApiTestCase):
     def test_website_redirect_location(self):
         self._test_unsupported_header('x-amz-website-redirect-location')
 
-    def test_aws_chunked(self):
-        self._test_unsupported_header('content-encoding', 'aws-chunked')
-        # https://docs.aws.amazon.com/AmazonS3/latest/API/sigv4-streaming.html
-        # has a multi-encoding example:
-        #
-        # > Amazon S3 supports multiple content encodings. For example:
-        # >
-        # >     Content-Encoding : aws-chunked,gzip
-        # > That is, you can specify your custom content-encoding when using
-        # > Signature Version 4 streaming API.
-        self._test_unsupported_header('Content-Encoding', 'aws-chunked,gzip')
-        # Some clients skip the content-encoding,
-        # such as minio-go and aws-sdk-java
-        self._test_unsupported_header('x-amz-content-sha256',
-                                      'STREAMING-AWS4-HMAC-SHA256-PAYLOAD')
-        self._test_unsupported_header('x-amz-decoded-content-length')
-
     def test_object_tagging(self):
         self._test_unsupported_header('x-amz-tagging')
 
@@ -948,7 +963,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'NotImplemented')
         self.assertEqual(
             {'501.NotImplemented': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:NotImplemented',
                          get_log_info(req.environ))
 
@@ -979,7 +994,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(status.split()[0], '200')
         self.assertEqual(
             {},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
 
         req = Request.blank('/bucket?tagging',
                             environ={'REQUEST_METHOD': 'PUT'},
@@ -990,7 +1005,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'NotImplemented')
         self.assertEqual(
             {'501.NotImplemented': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:NotImplemented',
                          get_log_info(req.environ))
 
@@ -1003,7 +1018,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'NotImplemented')
         self.assertEqual(
             {'501.NotImplemented': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:NotImplemented',
                          get_log_info(req.environ))
 
@@ -1022,7 +1037,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(elem.find('./ResourceType').text, 'ACL')
         self.assertEqual(
             {'405.MethodNotAllowed': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:MethodNotAllowed',
                          get_log_info(req.environ))
 
@@ -1133,7 +1148,10 @@ class TestS3ApiMiddleware(S3ApiTestCase):
             'X-Amz-Content-SHA256': '0' * 64}
         req = Request.blank('/bucket/object', environ=environ, headers=headers)
         req.content_type = 'text/plain'
-        status, headers, body = self.call_s3api(req)
+
+        # Test with ProxyLoggingMiddleware to verify access_user_id logging
+        app = ProxyLoggingMiddleware(self.s3api, {}, logger=self.logger)
+        status, headers, body = self.call_app(req, app=app)
         self.assertEqual(status.split()[0], '200', body)
         self.assertIn('swift.backend_path', req.environ)
         self.assertEqual('/v1/AUTH_test/bucket/object',
@@ -1142,6 +1160,14 @@ class TestS3ApiMiddleware(S3ApiTestCase):
             self.assertEqual(authz_header, headers['Authorization'])
             self.assertNotIn('X-Auth-Token', headers)
 
+        # Verify access_user_id is logged correctly for V4 signature
+        access_lines = self.logger.get_lines_for_level('info')
+        self.assertEqual(1, len(access_lines))
+        parts = access_lines[0].split()
+        self.assertEqual(' '.join(parts[3:7]),
+                         'GET /bucket/object HTTP/1.0 200')
+        self.assertEqual(parts[-1], 'test:tester')  # access_user_id
+
     def test_signature_v4_no_date(self):
         environ = {
             'REQUEST_METHOD': 'GET'}
@@ -1159,7 +1185,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'AccessDenied')
         self.assertEqual(
             {'403.AccessDenied.invalid_date': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.invalid_date',
                          get_log_info(req.environ))
 
@@ -1183,7 +1209,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
             'Missing required header for this request: x-amz-content-sha256')
         self.assertEqual(
             {'400.InvalidRequest': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:InvalidRequest',
                          get_log_info(req.environ))
 
@@ -1205,7 +1231,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
             self.assertIn(extra, body)
             self.assertEqual(
                 {metric: 1},
-                self.s3api.logger.logger.statsd_client.get_increment_counts())
+                self.s3api.logger.logger.statsd_client.get_stats_counts())
             self.assertEqual('s3:err:%s' % metric[4:],
                              get_log_info(req.environ))
 
@@ -1279,6 +1305,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
                     'Credential=X:Y/20110909/us-east-1/s3/aws4_request, '
                     'SignedHeaders=content-md5;content-type;date, '
                     'Signature=x',
+                'wsgi.input': io.BytesIO(),
             }
             fake_time = calendar.timegm((2011, 9, 9, 23, 36, 0))
             env.update(environ)
@@ -1300,9 +1327,9 @@ class TestS3ApiMiddleware(S3ApiTestCase):
                     patch.object(swift.common.middleware.s3api.s3request,
                                  'SERVICE', 'host'):
                 req = _get_req(path, environ)
-                hash_in_sts = req._string_to_sign().split(b'\n')[3]
+                hash_in_sts = req.sig_checker._string_to_sign().split(b'\n')[3]
                 self.assertEqual(hash_val, hash_in_sts.decode('ascii'))
-                self.assertTrue(req.check_signature(
+                self.assertTrue(req.sig_checker.check_signature(
                     'wJalrXUtnFEMI/K7MDENG+bPxRfiCYEXAMPLEKEY'))
 
         # all next data got from aws4_testsuite from Amazon
@@ -1471,7 +1498,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(status.split()[0], '403', body)
         self.assertEqual(
             {'403.AccessDenied.invalid_expires': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.invalid_expires',
                          get_log_info(req.environ))
 
@@ -1489,7 +1516,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(status.split()[0], '403', body)
         self.assertEqual(
             {'403.AccessDenied.invalid_expires': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.invalid_expires',
                          get_log_info(req.environ))
 
@@ -1606,7 +1633,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
                 statsd_client = self.s3api.logger.logger.statsd_client
                 self.assertEqual(
                     {'403.SignatureDoesNotMatch': 1},
-                    statsd_client.get_increment_counts())
+                    statsd_client.get_stats_counts())
             self.assertEqual('s3:err:SignatureDoesNotMatch',
                              get_log_info(req.environ))
 
@@ -1660,19 +1687,19 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         req, status, _, body = do_test(800)
         self.assertEqual('200 OK', status)
         self.assertFalse(
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
 
         req, status, _, body = do_test(-800)
         self.assertEqual('200 OK', status)
         self.assertFalse(
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
 
         req, status, _, body = do_test(1000)
         self.assertEqual('403 Forbidden', status)
         self.assertEqual(self._get_error_code(body), 'RequestTimeTooSkewed')
         self.assertEqual(
             {'403.RequestTimeTooSkewed': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:RequestTimeTooSkewed',
                          get_log_info(req.environ))
 
@@ -1681,7 +1708,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'RequestTimeTooSkewed')
         self.assertEqual(
             {'403.RequestTimeTooSkewed': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:RequestTimeTooSkewed',
                          get_log_info(req.environ))
 
@@ -1691,7 +1718,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         self.assertEqual(self._get_error_code(body), 'RequestTimeTooSkewed')
         self.assertEqual(
             {'403.RequestTimeTooSkewed': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:RequestTimeTooSkewed',
                          get_log_info(req.environ))
 
@@ -1716,14 +1743,14 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         req = do_test(ErrorResponse(status=403, msg='not good', reason='bad'))
         self.assertEqual(
             {'403.ErrorResponse.bad': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:ErrorResponse.bad',
                          get_log_info(req.environ))
 
         req = do_test(AccessDenied(msg='no entry', reason='invalid_date'))
         self.assertEqual(
             {'403.AccessDenied.invalid_date': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:AccessDenied.invalid_date',
                          get_log_info(req.environ))
 
@@ -1732,7 +1759,7 @@ class TestS3ApiMiddleware(S3ApiTestCase):
                                      reason='boom boom'))
         self.assertEqual(
             {'400.ka_boom.boom_boom': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            self.s3api.logger.logger.statsd_client.get_stats_counts())
         self.assertEqual('s3:err:ka_boom.boom_boom',
                          get_log_info(req.environ))
 
@@ -1750,17 +1777,45 @@ class TestS3ApiMiddleware(S3ApiTestCase):
         req.content_type = 'text/plain'
         log_conf = {'log_msg_template': '{method} {path} {log_info}'}
         app = ProxyLoggingMiddleware(self.s3api, log_conf, self.logger)
+        self.assertNotIn('swift.access_logging', req.environ)
         status, headers, body = self.call_app(req, app=app)
+        self.assertNotIn('swift.access_logging', req.environ)
 
         self.assertEqual(
-            {'403.AccessDenied.invalid_credential': 1},
-            self.s3api.logger.logger.statsd_client.get_increment_counts())
+            ['403.AccessDenied.invalid_credential'],
+            self.s3api.logger.statsd_client.get_increments())
         self.assertEqual('s3:err:AccessDenied.invalid_credential',
                          get_log_info(req.environ))
         self.assertEqual(
             ['HEAD /bucket/object s3:err:AccessDenied.invalid_credential'],
             self.logger.get_lines_for_level('info'))
 
+    def test_access_user_id_logging(self):
+        # verify that proxy logging gets access_user_id from S3 requests
+        environ = {'REQUEST_METHOD': 'GET'}
+        headers = {
+            'Authorization': 'AWS test:tester:hmac',
+            'Date': self.get_date_header()}
+        req = Request.blank('/bucket/object', environ=environ,
+                            headers=headers)
+
+        # Use a log template that includes access_user_id
+        log_conf = {
+            'log_msg_template':
+                '{method} {path} {account} {container} {object} '
+                '{status_int} {access_user_id}'
+        }
+        app = ProxyLoggingMiddleware(self.s3api, log_conf, self.logger)
+        status, headers, body = self.call_app(req, app=app)
+
+        # Should be successful GET
+        self.assertEqual(status.split()[0], '200')
+        # Verify the access_user_id is logged correctly
+        expected_log = ('GET /bucket/object AUTH_test bucket object '
+                        '200 test:tester')
+        self.assertEqual([expected_log],
+                         self.logger.get_lines_for_level('info'))
+
 
 if __name__ == '__main__':
     unittest.main()
