@@ -14,7 +14,7 @@
 # limitations under the License.
 
 import unittest
-import mock
+from unittest import mock
 
 try:
     # this test requires the dnspython package to be installed
@@ -24,7 +24,7 @@ except ImportError:
     skip = True
 else:  # executed if the try has no errors
     skip = False
-from swift.common import utils
+from swift.common import registry
 from swift.common.middleware import cname_lookup
 from swift.common.swob import Request, HTTPMovedPermanently
 
@@ -177,7 +177,8 @@ class TestCNAMELookup(unittest.TestCase):
                 self.cache[key] = value
 
         module = 'swift.common.middleware.cname_lookup.lookup_cname'
-        dns_module = 'dns.resolver.Resolver.query'
+        dns_module = 'swift.common.middleware.cname_lookup.' \
+            'dns.resolver.Resolver.query'
         memcache = memcache_stub()
 
         with mock.patch(module) as m:
@@ -311,16 +312,22 @@ class TestCNAMELookup(unittest.TestCase):
         app = cname_lookup.CNAMELookupMiddleware(FakeApp(), conf)
 
         def do_test(host):
-            req = Request.blank('/', environ={'REQUEST_METHOD': 'GET'},
-                                headers={'Host': host})
-            return app(req.environ, start_response)
+            with mock.patch.object(
+                app.resolver, 'query',
+                side_effect=dns.exception.DNSException,
+            ) as mock_lookup:
+                req = Request.blank('/', environ={'REQUEST_METHOD': 'GET'},
+                                    headers={'Host': host})
+                return app(req.environ, start_response), mock_lookup
 
         bad_domain = [b'CNAME lookup failed to resolve to a valid domain']
-        resp = do_test('c.badtest.com')
+        resp, mock_lookup = do_test('c.badtest.com')
         self.assertEqual(resp, bad_domain)
+        self.assertEqual(1, len(mock_lookup.mock_calls))
 
-        resp = do_test('storage.example.com')
+        resp, mock_lookup = do_test('storage.example.com')
         self.assertEqual(resp, [b'FAKE APP'])
+        self.assertEqual(0, len(mock_lookup.mock_calls))
 
     def test_resolution_to_storage_domain_exactly(self):
         conf = {'storage_domain': 'example.com',
@@ -360,7 +367,8 @@ class TestCNAMELookup(unittest.TestCase):
                 self.nameserver_ports = None
 
         mocked_resolver = MockedResolver()
-        dns_module = 'dns.resolver.Resolver'
+        dns_module = 'swift.common.middleware.cname_lookup.' \
+            'dns.resolver.Resolver'
 
         # If no nameservers provided in conf, resolver nameservers is unset
         for conf in [{}, {'nameservers': ''}]:
@@ -432,17 +440,17 @@ class TestCNAMELookup(unittest.TestCase):
 
 class TestSwiftInfo(unittest.TestCase):
     def setUp(self):
-        utils._swift_info = {}
-        utils._swift_admin_info = {}
+        registry._swift_info = {}
+        registry._swift_admin_info = {}
 
     def test_registered_defaults(self):
         cname_lookup.filter_factory({})
-        swift_info = utils.get_swift_info()
+        swift_info = registry.get_swift_info()
         self.assertIn('cname_lookup', swift_info)
         self.assertEqual(swift_info['cname_lookup'].get('lookup_depth'), 1)
 
     def test_registered_nondefaults(self):
         cname_lookup.filter_factory({'lookup_depth': '2'})
-        swift_info = utils.get_swift_info()
+        swift_info = registry.get_swift_info()
         self.assertIn('cname_lookup', swift_info)
         self.assertEqual(swift_info['cname_lookup'].get('lookup_depth'), 2)
