@@ -31,11 +31,10 @@
 import base64
 import hmac
 import itertools
-import mock
+from unittest import mock
 import unittest
 import hashlib
-import six
-from six.moves.urllib.parse import quote
+from urllib.parse import quote
 from time import time, strftime, gmtime
 
 from swift.common.middleware import tempauth, tempurl, proxy_logging
@@ -134,7 +133,7 @@ class TestTempURL(unittest.TestCase):
                          prefix=None):
         if not environ:
             environ = {}
-        if six.PY3 and isinstance(sig, six.binary_type):
+        if isinstance(sig, bytes):
             sig = sig.decode('utf-8')
         environ['QUERY_STRING'] = 'temp_url_sig=%s&temp_url_expires=%s' % (
             sig.replace('+', '%2B'), expires)
@@ -173,7 +172,7 @@ class TestTempURL(unittest.TestCase):
             key, hmac_body, hashlib.sha512).digest())
         self.assert_valid_sig(expires, path, [key], b'sha512:' + sig)
 
-        self.assertEqual(self.logger.statsd_client.get_increment_counts(), {
+        self.assertEqual(self.logger.statsd_client.get_stats_counts(), {
             'tempurl.digests.sha1': 1,
             'tempurl.digests.sha256': 2,
             'tempurl.digests.sha512': 1
