@@ -13,13 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import six
-import six.moves.cPickle as pickle
-import mock
+from unittest import mock
 import os
 import unittest
-from contextlib import closing
-from gzip import GzipFile
 from shutil import rmtree
 from tempfile import mkdtemp
 from test.debug_logger import debug_logger
@@ -45,20 +41,18 @@ class TestContainerUpdater(unittest.TestCase):
         rmtree(self.testdir, ignore_errors=1)
         os.mkdir(self.testdir)
         ring_file = os.path.join(self.testdir, 'account.ring.gz')
-        with closing(GzipFile(ring_file, 'wb')) as f:
-            pickle.dump(
-                RingData([[0, 1, 0, 1], [1, 0, 1, 0]],
-                         [{'id': 0, 'ip': '127.0.0.2', 'port': 12345,
-                           'replication_ip': '127.0.0.1',
-                           # replication_port may be overridden in tests but
-                           # include here for completeness...
-                           'replication_port': 67890,
-                           'device': 'sda1', 'zone': 0},
-                          {'id': 1, 'ip': '127.0.0.2', 'port': 12345,
-                           'replication_ip': '127.0.0.1',
-                           'replication_port': 67890,
-                           'device': 'sda1', 'zone': 2}], 30),
-                f)
+        RingData([[0, 1, 0, 1], [1, 0, 1, 0]],
+                 [{'id': 0, 'ip': '127.0.0.2', 'port': 12345,
+                   'replication_ip': '127.0.0.1',
+                   # replication_port may be overridden in tests but
+                   # include here for completeness...
+                   'replication_port': 67890,
+                   'device': 'sda1', 'zone': 0, 'region': 1},
+                  {'id': 1, 'ip': '127.0.0.2', 'port': 12345,
+                   'replication_ip': '127.0.0.1',
+                   'replication_port': 67890,
+                   'device': 'sda1', 'zone': 2, 'region': 1}],
+                 30).save(ring_file)
         self.devices_dir = os.path.join(self.testdir, 'devices')
         os.mkdir(self.devices_dir)
         self.sda1 = os.path.join(self.devices_dir, 'sda1')
@@ -313,8 +307,6 @@ class TestContainerUpdater(unittest.TestCase):
                              container='\xce\xa9')
         cb.initialize(normalize_timestamp(1), 0)
         obj_name = u'\N{GREEK CAPITAL LETTER OMEGA}'
-        if six.PY2:
-            obj_name = obj_name.encode('utf-8')
         cb.put_object(obj_name, normalize_timestamp(2), 3, 'text/plain',
                       '68b329da9893e34099c7d8ad5cb9c940')
 
